import { GridContent } from "@ant-design/pro-layout";
import { Card, DatePicker, Radio, Select, message } from "antd";
import React, { useState, useEffect } from 'react';
import * as echarts from 'echarts';
import moment from 'moment';
import api from "./service";
const { RangePicker } = DatePicker;

const WelcomeReport = () => {
  const [storeList, setStoreList] = useState();
  const [deviceList, setDeviceList] = useState();
  const [store, setStore] = useState();
  const [device, setDevice] = useState();
  const [dateRange, setDateRange] = useState([
    moment().subtract(14, 'days').startOf('day'),
    moment().endOf('day')
  ]);
  const [grain, setGrain] = useState();
  const grainMap = {
    'year': '年',
    'month': '月',
    'week': '周',
    'day': '日'
  };

  useEffect(() => {
    const resizeChart = () => {
      const charts = ['recipeUseBar', 'recipeUseLine', 'batchingUseBar', 'batchingUseLine'];
      charts.forEach(chartId => {
        const chartDom = document.getElementById(chartId);
        const myChart = echarts.getInstanceByDom(chartDom);
        if (myChart) {
          myChart.resize();
        }
      });
    };
    api.getSearchList().then((r) => {
      if (r.data) {
        var storeList = r.data.storeList;
        var deviceList = r.data.deviceList;
        setStoreList(storeList);
        setDeviceList(deviceList);
        api.getReportSearchLog().then((r2) => {
          if (r2.data.grain != null) {
            setStore(r2.data.storeName);
            setDevice(r2.data.deviceName);
            setDateRange([moment(r2.data.startTime), moment(r2.data.endTime)]);
            setGrain(r2.data.grain);
            SearchData(r2.data.storeName, r2.data.deviceName, r2.data.startTime, r2.data.endTime, r2.data.grain);
          } else {
            setStore(storeList[0]?.value);
            setDevice(deviceList[0]?.value);
            setGrain('day');
            SearchData(storeList[0]?.value, deviceList[0]?.value, dateRange[0].startOf('day').format('YYYY-MM-DD HH:mm:ss'), dateRange[1].endOf('day').format('YYYY-MM-DD HH:mm:ss'), "day");
          }
        });
      }
    });
    // 监听窗口大小变化
    window.addEventListener('resize', resizeChart);
    // 清理监听器
    return () => {
      window.removeEventListener('resize', resizeChart);
    };
  }, []);

  const SearchData = (store, device, startDate, endDate, grain) => {
    api.getMainReport({ "storeName": store, "deviceName": device, "startTime": startDate, "endTime": endDate, "grain": grain }).then((r) => {
      if (r.data) {
        SetRecipeUseBar(r.data.recipeUseBar)
        SetRecipeUseLine(r.data.recipeUseLine)
        SetBatchingUseBar(r.data.batchingUseBar)
        SetBatchingUseLine(r.data.batchingUseLine)
      }
    })
  }

  const SetRecipeUseBar = (data) => {
    var chartDom = document.getElementById('recipeUseBar');
    var myChart = echarts.init(chartDom);
    var option;
    option = {
      title: {
        text: '配方使用排行',
        left: 'center',
        top: '10',
        textStyle: {
          fontSize: 18,
          fontWeight: 'bold',
        }
      },
      tooltip: {
        trigger: 'axis',
        axisPointer: {
          type: 'shadow'
        },
        formatter: function (params) {
          const { name, value } = params[0];
          return `${name}: ${value}`;
        }
      },
      xAxis: {
        type: 'value'
      },
      yAxis: {
        type: 'category',
        data: data?.names.reverse()
      },
      series: [
        {
          data: data?.values.sort((a, b) => a - b),
          type: 'bar'
        }
      ]
    };
    option && myChart.setOption(option);
  }

  const SetRecipeUseLine = (data) => {
    var chartDom = document.getElementById('recipeUseLine');
    var myChart = echarts.getInstanceByDom(chartDom);
    if (myChart) {
      myChart.dispose();
    }
    var myChart = echarts.init(chartDom);
    var option;
    data?.values.forEach(t => {
      t.type = 'line',
        t.smooth = true
    });
    option = {
      title: {
        text: '配方使用趋势',
        top: '10',
        textStyle: {
          fontSize: 18,
          fontWeight: 'bold',
        }
      },
      tooltip: {
        trigger: 'axis',
      },
      legend: {
        data: data?.names
      },
      grid: {
        left: '3%',
        right: '4%',
        bottom: '3%',
        containLabel: true
      },
      xAxis: {
        type: 'category',
        boundaryGap: false,
        data: data?.xcoos,
        axisLabel: {
          rotate: 55
        }
      },
      yAxis: {
        type: 'value'
      },
      series: data?.values
    };
    option && myChart.setOption(option);
  };

  const SetBatchingUseBar = (data) => {
    var chartDom = document.getElementById('batchingUseBar');
    var myChart = echarts.init(chartDom);
    var option;
    option = {
      title: {
        text: '物料使用排行',
        left: 'center',
        top: '10',
        textStyle: {
          fontSize: 18,
          fontWeight: 'bold',
        }
      },
      tooltip: {
        trigger: 'axis',
        axisPointer: {
          type: 'shadow'
        },
        formatter: function (params) {
          const { name, value } = params[0];
          return `${name}: ${value}`;
        }
      },
      xAxis: {
        type: 'value'
      },
      yAxis: {
        type: 'category',
        data: data?.names.reverse()
      },
      series: [
        {
          data: data?.values.sort((a, b) => a - b),
          type: 'bar'
        }
      ]
    };
    option && myChart.setOption(option);
  }

  const SetBatchingUseLine = (data) => {
    var chartDom = document.getElementById('batchingUseLine');
    var myChart = echarts.getInstanceByDom(chartDom);
    if (myChart) {
      myChart.dispose();
    }
    var myChart = echarts.init(chartDom);
    var option;
    data?.values.forEach(t => {
      t.type = 'line',
        t.smooth = true
    });
    option = {
      title: {
        text: '物料使用趋势',
        top: '10',
        textStyle: {
          fontSize: 18,
          fontWeight: 'bold',
        }
      },
      tooltip: {
        trigger: 'axis'
      },
      legend: {
        data: data?.names
      },
      grid: {
        left: '3%',
        right: '4%',
        bottom: '3%',
        containLabel: true
      },
      xAxis: {
        type: 'category',
        boundaryGap: false,
        data: data?.xcoos,
        axisLabel: {
          rotate: 55
        }
      },
      yAxis: {
        type: 'value'
      },
      series: data?.values
    };
    option && myChart.setOption(option);
  };

  return (
    <GridContent>
      <Card style={{ marginBottom: 10 }}>
        <div style={{ display: 'flex', alignItems: 'center', width: '100%' }}>
          <span style={{ marginLeft: 10 }}>门店:</span>
          <Select
            value={store}
            style={{ width: '12%', marginLeft: 10 }}
            options={storeList}
            placeholder="请选择门店"
            allowClear
            onChange={(e) => {
              setStore(e)
              SearchData(e, device, dateRange[0].startOf('day').format('YYYY-MM-DD HH:mm:ss'), dateRange[1].endOf('day').format('YYYY-MM-DD HH:mm:ss'), grain)
            }}
          />
          <span style={{ marginLeft: 10 }}>设备:</span>
          <Select
            value={device}
            style={{ width: '12%', marginLeft: 10 }}
            options={deviceList}
            placeholder="请选择设备"
            allowClear
            onChange={(e) => {
              setDevice(e)
              SearchData(store, e, dateRange[0].startOf('day').format('YYYY-MM-DD HH:mm:ss'), dateRange[1].endOf('day').format('YYYY-MM-DD HH:mm:ss'), grain)
            }}
          />
          <span style={{ marginLeft: 10 }}>使用时间:</span>
          <RangePicker style={{ width: '15%', marginLeft: 10 }} value={dateRange} allowClear={false}
            onChange={(date, dateStrings) => {
              let tempDate = ['', '']
              if (date != null) {
                tempDate = [
                  moment(moment(new Date(dateStrings[0])).format('YYYY-MM-DD HH:mm:ss')),
                  moment(moment(new Date(dateStrings[1])).format('YYYY-MM-DD HH:mm:ss')),
                ]
                const duration = moment.duration(tempDate[1].diff(tempDate[0]));
                const years = duration.asYears();
                const months = duration.asMonths();
                const weeks = duration.asWeeks();
                const days = duration.asDays();
                if (
                  (grain === 'year' && years > 15) ||
                  (grain === 'month' && months > 15) ||
                  (grain === 'week' && weeks > 15) ||
                  (grain === 'day' && days > 15)
                ) {
                  message.error(`选择的${grainMap[grain]}范围超过限制的15${grainMap[grain]}`);
                  return;
                }
              }
              setDateRange(tempDate);
              SearchData(store, device, date[0].startOf('day').format('YYYY-MM-DD HH:mm:ss'), date[1].endOf('day').format('YYYY-MM-DD HH:mm:ss'), grain)
            }}
          />
          <Radio.Group style={{ marginLeft: 10 }} value={grain}
            onChange={(e) => {
              const newGrain = e.target.value;
              const duration = moment.duration(dateRange[1].diff(dateRange[0]));
              const years = duration.asYears();
              const months = duration.asMonths();
              const weeks = duration.asWeeks();
              const days = duration.asDays();
              if (
                (newGrain === 'year' && years > 15) ||
                (newGrain === 'month' && months > 15) ||
                (newGrain === 'week' && weeks > 15) ||
                (newGrain === 'day' && days > 15)
              ) {
                message.error(`选择的${grainMap[newGrain]}范围超过限制的15${grainMap[newGrain]}`);
                return;
              }
              setGrain(e.target.value)
              SearchData(store, device, dateRange[0].startOf('day').format('YYYY-MM-DD HH:mm:ss'), dateRange[1].endOf('day').format('YYYY-MM-DD HH:mm:ss'), e.target.value)
            }}>
            <Radio value='year'>年</Radio>
            <Radio value='month'>月</Radio>
            <Radio value='week'>周</Radio>
            <Radio value='day'>日</Radio>
          </Radio.Group>
        </div>
      </Card>
      <Card>
        <div style={{ display: 'flex', width: '100%', height: 350, margin: -24 }}>
          <div id="recipeUseBar" style={{ width: '40%', height: 330 }}></div>
          <div id="recipeUseLine" style={{ width: '63%', height: 330 }}></div>
        </div>
        <div style={{ display: 'flex', width: '100%', height: 350, margin: -24, marginTop: 10 }}>
          <div id="batchingUseBar" style={{ width: '40%', height: 330 }}></div>
          <div id="batchingUseLine" style={{ width: '63%', height: 330 }}></div>
        </div>
      </Card>
    </GridContent>
  )
}

export default WelcomeReport;