import { PlusOutlined } from '@ant-design/icons';
import { Button, message, Popconfirm } from 'antd';
import React, { useState, useRef } from 'react';
import { PageContainer } from '@ant-design/pro-layout';
import ProTable from '@ant-design/pro-table';
import CreateForm from './components/CreateForm';
import api from './service';
import { randomString } from '../../comm';

const batchinginfo = () => {
  const actionRef = useRef();
  const [createModalVisible, handleModalVisible] = useState();
  const [stepFormValues, setStepFormValues] = useState({});
  const [selectedRowsState, setSelectedRows] = useState();
  const uintList = [
    { value: '1', label: 'g' },
    { value: '2', label: 'kg' },
  ];
  const typeList = [
    { value: '1', label: '液体料' },
    { value: '2', label: '主料' },
  ];
  const handleAdd = async (fields) => {
    await api.add(fields).then((r) => {
      if (r.data) {
        message.success('添加成功');
      } else {
        message.error(r.errors);
      }
    });
  };
  const handleUpdate = async (fields) => {
    await api.update(fields).then((r) => {
      if (r.data) {
        message.success('修改成功');
      } else {
        message.error(r.errors);
      }
    });
  };
  const BatchDeletion = () => {
    return (
      selectedRowsState?.length > 0 &&
      (
        <Popconfirm
          title="确认删除吗?"
          onConfirm={onClickdele}
          okText="确定"
          cancelText="取消"
        >
          <Button type="primary">批量删除</Button>
        </Popconfirm>
      ))
  }
  const onClickdele = () => {
    handleRemove(selectedRowsState);
    setSelectedRows([]);
    actionRef.current?.reloadAndRest?.();
  }
  const handleRemove = async (selectedRows) => {
    if (!selectedRows) return true;
    await api.delete(selectedRows.map((row) => row.id)).then((r) => {
      if (r.data) {
        message.success('删除成功');
        actionRef.current.reload();
      } else {
        message.error(r.errors);
      }
    });
    return true;
  };
  const columns = [
    {
      title: '主键',
      dataIndex: 'id',
      tip: 'key',
      hideInSearch: true,
      hideInTable: true
    },
    {
      title: '物料名称',
      dataIndex: 'name',
      ellipsis: true,
    },
    {
      title: '物料编码',
      dataIndex: 'code',
      ellipsis: true,
      hideInSearch: true,
    },
    {
      title: '物料类别',
      dataIndex: 'type',
      valueType: 'select',
      fieldProps: {
        options: typeList,
      },
      hideInSearch: true,
    },
    {
      title: '物料单位',
      dataIndex: 'stockUint',
      valueType: 'select',
      fieldProps: {
        options: uintList,
      },
      hideInSearch: true,
    },
    {
      title: '创建时间',
      dataIndex: 'createAt',
      valueType: 'date',
      hideInForm: true,
      hideInSearch: true,
    },
    {
      title: '操作',
      dataIndex: 'option',
      valueType: 'option',
      fixed: 'right',
      width: 350,
      render: (_, record) => [
        <a
          onClick={() => {
            handleModalVisible(true);
            setStepFormValues(record);
          }}
        >
          更新
        </a>
        ,
        <Popconfirm
          type="primary"
          key="primary"
          title="确认删除吗？"
          okText="是"
          cancelText="否"
          onConfirm={() => {
            api.deleteBatching([record.id]).then((r) => {
              if (r.succeeded) {
                message.success('删除成功');
                actionRef.current.reload();
              } else {
                message.error(r.errors);
              }
            });
          }}
        >
          <a href="#">删除</a>
        </Popconfirm>,
      ],
    }
  ]

  return (
    <PageContainer
      header={{
        title: '',
        breadcrumb: {},
      }}
    >
      <ProTable
        headerTitle="物料列表"
        actionRef={actionRef}
        rowKey="id"
        pagination={{ defaultPageSize: 10 }}
        search={{
          labelWidth: 120,
        }}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              var values = { code: randomString(4), type: 2, stockUint:1 }
              setStepFormValues(values);
              handleModalVisible(true);
            }}
          >
            <PlusOutlined /> 新建
          </Button>,
          <BatchDeletion />
        ]}
        request={async (params) => {
          let batchingData = [];
          var total = 0;
          await api.getBatchingPage(params).then((r) => {
            batchingData = r.data.data;
            total = r.data.total;
          });
          return {
            data: batchingData,
            total: total,
          };
        }}
        columns={columns}
        rowSelection={{
          onChange: (_, selectedRows) => {
            setSelectedRows(selectedRows);
          },
        }}
      />
      <CreateForm
        uintList={uintList}
        typeList={typeList}
        onFinish={async (value) => {
          setStepFormValues({});
          if (value.id) {
            await handleUpdate(value);
          } else {
            await handleAdd(value);
          }
          handleModalVisible(false);
          actionRef.current.reload();
        }}
        onCancel={() => {
          handleModalVisible(false);
          setStepFormValues({});
        }}
        modalVisible={createModalVisible}
        values={stepFormValues || {}}
      />
    </PageContainer>
  )
}

export default batchinginfo;