import { PlusOutlined } from '@ant-design/icons';
import { Button, message, Popconfirm, Modal, Table } from 'antd';
import React, { useState, useRef, useEffect } from 'react';
import { PageContainer } from '@ant-design/pro-layout';
import ProTable from '@ant-design/pro-table';
import CreateForm from './components/CreateForm';
import api from './service';
import RecipeInfo from '../../recipe/recipeinfo/index'
import RecipeTemplate from '../../recipe/recipetemplate/index'

const deviceinfo = () => {
  const actionRef = useRef();
  const [autoKey, setAutokey] = useState();
  const [selectedRowsState, setSelectedRows] = useState();
  const [storeList, setStoreList] = useState([]);
  const [createModalOpen, handleModalOpen] = useState();
  const [stepFormValues, setStepFormValues] = useState({});
  const [activationLogOpen, setActivationLogOpen] = useState(false);
  const [activationLogs, setActivationLogs] = useState();
  const [recipeInfoOpen, setRecipeInfoOpen] = useState(false);
  const [recipeTemplateOpen, setRecipeTemplateOpen] = useState(false);
  const enableList = [
    { value: 1, label: '启用' },
    { value: 0, label: '停用' },
  ];
  const activationList = [
    { value: 1, label: '已激活' },
    { value: 0, label: '未激活' },
  ];
  useEffect(() => {
    getAllStoreList()
  }, []);
  function getAllStoreList() {
    api.getAllStoreList().then((r) => {
      var data = r.data;
      const storeList = [];
      data.forEach((item) => {
        storeList.push({
          value: item.id,
          label: item.name
        })
      })
      setStoreList(storeList);
    });
  }
  const BatchDeletion = () => {
    return (
      selectedRowsState?.length > 0 &&
      (
        <Popconfirm
          title="确认删除吗?"
          onConfirm={onClickdele}
          okText="确定"
          cancelText="取消"
        >
          <Button type="primary">批量删除</Button>
        </Popconfirm>
      ))
  }
  const onClickdele = () => {
    handleRemove(selectedRowsState);
    setSelectedRows([]);
    actionRef.current?.reloadAndRest?.();
  }
  const handleRemove = async (selectedRows) => {
    if (!selectedRows) return true;
    await api.deleteDevice(selectedRows.map((row) => row.id)).then((r) => {
      if (r.data) {
        message.success('删除成功');
        actionRef.current.reload();
      } else {
        message.error(r.errors);
      }
    });
    return true;
  };

  const columns = [
    {
      title: '主键',
      dataIndex: 'id',
      tip: 'key',
      hideInSearch: true,
      hideInTable: true
    },
    {
      title: '设备名称',
      dataIndex: 'name',
      ellipsis: true,
    },
    {
      title: '门店名称',
      dataIndex: 'storeId',
      valueType: 'select',
      hideInSearch: true,
      fieldProps: {
        options: storeList,
      },
    },
    {
      title: '使用情况',
      dataIndex: 'isEnable',
      valueType: 'select',
      hideInSearch: true,
      fieldProps: {
        options: enableList,
      },
    },
    {
      title: '激活情况',
      dataIndex: 'isActivation',
      valueType: 'select',
      hideInSearch: true,
      fieldProps: {
        options: activationList,
      },
    },
    {
      title: '设备唯一key',
      dataIndex: 'autoKey',
      ellipsis: true,
      hideInSearch: true,
    },
    {
      title: '备注',
      dataIndex: 'remark',
      ellipsis: true,
      hideInSearch: true,
    },
    {
      title: '操作',
      dataIndex: 'option',
      valueType: 'option',
      fixed: 'right',
      width: 350,
      render: (_, record) => [
        <a
          onClick={() => {
            setStepFormValues(record);
            handleModalOpen(true);
          }}
        >
          更新
        </a>,
        <a
          onClick={() => {
            setAutokey(record.autoKey)
            setRecipeInfoOpen(true)
          }}
        >
          配方列表
        </a>,
        <a
          onClick={() => {
            setAutokey(record.autoKey)
            setRecipeTemplateOpen(true)
          }}
        >
          配方模版
        </a>,
        <a
          onClick={() => {
            setActivationLogs(record.logList)
            setActivationLogOpen(true)
          }}
        >
          激活记录
        </a>,
        <Popconfirm
          type="primary"
          key="primary"
          title="确认删除吗？"
          okText="是"
          cancelText="否"
          onConfirm={() => {
            api.deleteDevice([record.id]).then((r) => {
              if (r.succeeded) {
                message.success('删除成功');
                actionRef.current.reload();
              } else {
                message.error(r.errors);
              }
            });
          }}
        >
          <a href="#">删除</a>
        </Popconfirm>,
      ],
    }
  ]

  const logColumns = [
    {
      title: '主键',
      dataIndex: 'id',
      tip: 'key',
      hideInSearch: true,
      hideInTable: true
    },
    {
      title: '设备',
      dataIndex: 'deviceName',
      ellipsis: true,
    },
    {
      title: '设备Key',
      dataIndex: 'autoKey',
      ellipsis: true,
    },
    {
      title: '激活方式',
      dataIndex: 'onlineKey',
      render: (text, record) => (record.onlineKey ? '在线' : '离线'),
    },
    {
      title: '激活码',
      width: 200,
      render: (text, record) => {
        return record.onlineKey ? record.onlineKey : record.offlineKey;
      },
      ellipsis: true,
    },
    {
      title: '过期时间',
      dataIndex: 'effectiveDate',
      ellipsis: true,
    },
    {
      title: '激活时间',
      dataIndex: 'activationDate',
      ellipsis: true,
    },
    {
      title: '激活加盟商',
      dataIndex: 'company',
      ellipsis: true,
    },
  ]

  return (
    <PageContainer
      header={{
        title: '',
        breadcrumb: {},
      }}
    >
      <ProTable
        headerTitle="设备列表"
        actionRef={actionRef}
        rowKey="id"
        pagination={{ defaultPageSize: 10 }}
        search={{
          labelWidth: 120,
        }}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              var values = { isEnable: 1 }
              setStepFormValues(values);
              handleModalOpen(true);
            }}
          >
            <PlusOutlined /> 新建
          </Button>,
          <BatchDeletion />
        ]}
        request={async (params) => {
          let storeData = [];
          var total = 0;
          await api.getDevicePage(params).then((r) => {
            storeData = r.data.data;
            total = r.data.total;
          });
          return {
            data: storeData,
            total: total,
          };
        }}
        columns={columns}
        rowSelection={{
          onChange: (_, selectedRows) => {
            setSelectedRows(selectedRows);
          },
        }}
      />

      <CreateForm
        storeList={storeList}
        enableList={enableList}
        onFinish={async (value) => {
          await api.updateDevice(value).then(r => {
            if (r.data) {
              if (value.id == undefined) {
                message.success("添加成功")
              }
              else {
                message.success("修改成功")
              }
            }
            else {
              message.error(r.errors)
            }
          })
          handleModalOpen(false);
          setStepFormValues({});
          actionRef.current.reload();
        }}
        onCancel={() => {
          handleModalOpen(false);
          setStepFormValues({});
        }}
        modalOpen={createModalOpen}
        values={stepFormValues || {}}
      />

      <Modal
        title='激活记录'
        width={1000}
        open={activationLogOpen}
        onCancel={() => {
          setActivationLogOpen(false)
        }}
        footer={null}
        maskClosable={false}
        destroyOnClose
      >
        <ProTable
          search={false}
          options={false}
          dataSource={activationLogs}
          columns={logColumns}
        />
      </Modal>

      <Modal
        title='配方列表'
        width={1500}
        style={{ top: 20 }}
        bodyStyle={{ padding: '0px', minHeight: '800px' }}
        open={recipeInfoOpen}
        onCancel={() => {
          setRecipeInfoOpen(false)
        }}
        footer={null}
        maskClosable={false}
        destroyOnClose
      >
        <RecipeInfo
          autoKey={autoKey}
        />
      </Modal>

      <Modal
        title='配方模版'
        width={1500}
        style={{ top: 20 }}
        bodyStyle={{ padding: '0px', minHeight: '850px' }}
        open={recipeTemplateOpen}
        onCancel={() => {
          setRecipeTemplateOpen(false)
        }}
        footer={null}
        maskClosable={false}
        destroyOnClose
      >
        <RecipeTemplate
          autoKey={autoKey}
        />
      </Modal>

    </PageContainer>
  )
}

export default deviceinfo;