import { PlusOutlined } from '@ant-design/icons';
import { Button, message, Popconfirm, Modal } from 'antd';
import React, { useState, useRef, useEffect } from 'react';
import { PageContainer } from '@ant-design/pro-layout';
import ProTable from '@ant-design/pro-table';
import CreateForm from './components/CreateForm';
import api from './service';
import RecipeTemplate from '../../recipe/recipetemplate/index'

const recipegrouptemplate = () => {
  const actionRef = useRef();
  const [createModalVisible, handleModalVisible] = useState();
  const [stepFormValues, setStepFormValues] = useState({});
  const [selectedRowsState, setSelectedRows] = useState();
  const [recipeTemplateOpen, setRecipeTemplateOpen] = useState();

  const BatchDeletion = () => {
    return (
      selectedRowsState?.length > 0 &&
      (
        <Popconfirm
          title="确认删除吗?"
          onConfirm={onClickdele}
          okText="确定"
          cancelText="取消"
        >
          <Button type="primary">批量删除</Button>
        </Popconfirm>
      ))
  }
  const onClickdele = () => {
    handleRemove(selectedRowsState);
    setSelectedRows([]);
    actionRef.current?.reloadAndRest?.();
  }
  const handleRemove = async (selectedRows) => {
    if (!selectedRows) return true;
    await api.deleteRecipeGroupTemplate(selectedRows.map((row) => row.id)).then((r) => {
      if (r.data) {
        message.success('删除成功');
        actionRef.current.reload();
      } else {
        message.error(r.errors);
      }
    });
    return true;
  };

  const columns = [
    {
      title: '主键',
      dataIndex: 'id',
      tip: 'key',
      hideInSearch: true,
      hideInTable: true
    },
    {
      title: '模版名称',
      dataIndex: 'name',
      ellipsis: true,
    },
    {
      title: '模版描述',
      dataIndex: 'describe',
      hideInSearch: true,
      ellipsis: true,
    },
    {
      title: '操作',
      dataIndex: 'option',
      valueType: 'option',
      fixed: 'right',
      width: 'auto',
      render: (_, record) => [
        <a
          onClick={() => {
            handleModalVisible(true);
            setStepFormValues(record);
          }}
        >
          更新
        </a>,
        <a
          onClick={() => {
            setRecipeTemplateOpen(true);
            setStepFormValues(record);
          }}
        >
          设置模版
        </a>
        ,
        <Popconfirm
          type="primary"
          key="primary"
          title="确认删除吗？"
          okText="是"
          cancelText="否"
          onConfirm={() => {
            api.deleteRecipeGroupTemplate([record.id]).then((r) => {
              if (r.succeeded) {
                message.success('删除成功');
                actionRef.current.reload();
              } else {
                message.error(r.errors);
              }
            });
          }}
        >
          <a href="#">删除</a>
        </Popconfirm>,
      ],
    }
  ]

  return (
    <PageContainer
      header={{
        title: '',
        breadcrumb: {},
      }}
    >
      <ProTable
        headerTitle="配方模版列表"
        actionRef={actionRef}
        rowKey="id"
        pagination={{ defaultPageSize: 10 }}
        search={{
          labelWidth: 120,
        }}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              setStepFormValues({});
              handleModalVisible(true);
            }}
          >
            <PlusOutlined /> 新建
          </Button>,
          <BatchDeletion />
        ]}
        request={async (params) => {
          let templateData = [];
          var total = 0;
          await api.getRecipeGroupTemplatePage(params).then((r) => {
            templateData = r.data.data;
            total = r.data.total;
          });
          return {
            data: templateData,
            total: total,
          };
        }}
        columns={columns}
        rowSelection={{
          onChange: (_, selectedRows) => {
            setSelectedRows(selectedRows);
          },
        }}
      />

      <CreateForm
        onFinish={async (value) => {
          setStepFormValues({});
          await api.updateRecipeGroupTemplate(value).then((r) => {
            if (r.data) {
              if (value.id == undefined) {
                message.success("添加成功")
              }
              else {
                message.success("修改成功")
              }
            } else {
              message.error(r.errors)
            }
          })
          handleModalVisible(false);
          actionRef.current.reload();
        }}
        onCancel={() => {
          handleModalVisible(false);
          setStepFormValues({});
        }}
        modalVisible={createModalVisible}
        values={stepFormValues || {}}
      />

      <Modal
        title={'配方模版(' + stepFormValues.name + ')'}
        width={1500}
        style={{ top: 20 }}
        bodyStyle={{ padding: '0px', minHeight: '850px' }}
        open={recipeTemplateOpen}
        onCancel={() => {
          setRecipeTemplateOpen(false)
        }}
        footer={null}
        maskClosable={false}
        destroyOnClose
      >
        <RecipeTemplate
          groupTempId={stepFormValues.id}
        />
      </Modal>
    </PageContainer>
  )
}

export default recipegrouptemplate;