import { Button, Input, Modal, Select, message, Popconfirm } from 'antd';
import { useEffect, useState } from 'react';
import api from '../service'
import ProTable from '@ant-design/pro-table';
import RepeatForm from './RepeatForm';

const CopyForm = (props) => {
  const [dataSource, setDataSource] = useState([]);
  const [selectAutoKey, setSelectAutoKey] = useState();
  const [selectedRowsState, setSelectedRows] = useState();
  const [inputValue, setInputValue] = useState('');
  const [repeatRecipes, setRepeatRecipes] = useState([]);
  const [repeatOpen, setRepeatOpen] = useState(false);
  useEffect(() => {
    setDataSource([])
    setSelectAutoKey(null)
  }, [props.values])
  const columns = [
    {
      title: '主键',
      dataIndex: 'id',
      tip: 'key',
      hideInSearch: true,
      hideInTable: true
    },
    {
      title: '配方名称',
      dataIndex: 'name',
      ellipsis: true,
    },
  ]

  const handleSelectChange = (value) => {
    setSelectAutoKey(value);
    setSelectedRows([]);
    if (value != undefined) {
      api.getAllRecipeList(value).then((r) => {
        if (r.data) {
          setDataSource(r.data);
        }
      });
    } else {
      setDataSource([]);
    }
  };

  const importRecipe = () => {
    const repeatHide = message.loading('查找重复数据中');
    setTimeout(() => {
      api.getRepeatRecipeList(selectedRowsState.map((row) => row.name), selectAutoKey, props.autoKey).then((r) => {
        if (r.data) {
          if (r.data.length > 0) {
            setRepeatRecipes(r.data)
            setRepeatOpen(true)
            repeatHide()
          } else {
            repeatHide()
            const hide = message.loading('正在导入');
            api.copyRecipeList(selectedRowsState.map((row) => row.name), '', selectAutoKey, props.autoKey).then((r) => {
              if (r.data) {
                message.success("导入成功")
              } else {
                message.error(r.errors)
              }
            })
            hide()
          }
        }
        else {
          repeatHide()
          message.error(r.errors)
        }
      })
    }, 1000);
  }

  const importAllRecipe = () => {
    const repeatHide = message.loading('查找重复数据中');
    setTimeout(() => {
      api.getRepeatRecipeList('', selectAutoKey, props.autoKey).then((r) => {
        if (r.data) {
          if (r.data.length > 0) {
            setRepeatRecipes(r.data)
            setRepeatOpen(true)
            repeatHide()
          } else {
            repeatHide()
            const hide = message.loading('正在导入');
            api.copyRecipeList('', '', selectAutoKey, props.autoKey).then((r) => {
              if (r.data) {
                message.success("导入成功")
              } else {
                message.error(r.errors)
              }
            })
            hide()
          }
        }
        else {
          repeatHide()
          message.error(r.errors)
        }
      })
    }, 1000);
  }

  return (
    <>
      <Modal
        title='导入数据'
        width={640}
        bodyStyle={{ padding: '10px' }}
        open={props.copyOpen}
        onCancel={props.onCancel}
        footer={null}
        maskClosable={false}
        destroyOnClose
      >
        <span style={{ marginLeft: 25 }}>数据来源:</span>
        <Select
          showSearch
          style={{ width: 300, marginLeft: 10 }}
          optionFilterProp="label"
          options={props.values}
          placeholder="请选择数据来源"
          allowClear
          onChange={handleSelectChange}
        />
        {
          selectAutoKey != undefined ? (
            <Popconfirm
              type="primary"
              title="是否导入该设备的全部配方"
              okText="是"
              cancelText="否"
              onConfirm={importAllRecipe}
            >
              <Button
                type="primary"
                style={{ marginLeft: 10 }}
              >
                导入全部
              </Button>
            </Popconfirm>
          ): ""
        }
        <br />
        <span style={{ marginLeft: 25, marginTop: 10 }}>配方名称:</span>
        <Input
          style={{ width: 300, marginLeft: 10, marginTop: 10 }}
          onChange={(e) => {
            setInputValue(e.target.value)
          }}
        />
        <Button
          type="primary"
          style={{ marginLeft: 10, marginTop: 10 }}
          onClick={() => {
            api.getRecipeListWithName(inputValue, selectAutoKey).then((r) => {
              if (r.data) {
                setDataSource(r.data)
              }
            })
          }}
        >
          查询
        </Button>
        <ProTable
          rowKey="id"
          columns={columns}
          dataSource={dataSource}
          options={false}
          search={false}
          style={{ marginTop: 10 }}
          pagination={{ defaultPageSize: 10 }}
          rowSelection={{
            selectedRowKeys: selectedRowsState?.map((row) => row.id),
            onChange: (selectedRowKeys, selectedRows) => {
              setSelectedRows(selectedRows);
            },
          }}
        />
        {
          selectedRowsState?.length > 0 && (
            <Button
              type="primary"
              style={{ float: 'right', marginTop: -25 }}
              onClick={importRecipe}
            >
              导入
            </Button>
          )
        }
      </Modal>

      <RepeatForm
        onFinish={async (data) => {
          const transformedData = Object.entries(data).map(([key, value]) => ({
            key,
            value
          }));
          var list = [];
          transformedData.forEach((item) => {
            list.push({
              key: item.key,
              value: Boolean(item.value)
            });
          });
          var notReport = selectedRowsState.length == list.length && list.every(t => t.value == false);
          if(!notReport)
          {
            const hide = message.loading('正在导入');
            setTimeout(() => {
              api.copyRecipeList(selectedRowsState.map((row) => row.name), list.filter(row => row.value === false).map(row => row.key).join(','), selectAutoKey, props.autoKey).then((r) => {
                if (r.data) {
                  message.success("导入成功")
                } else {
                  message.error(r.errors)
                }
                hide();
              })
            }, 1000);
          }
          setRepeatOpen(false);
          setRepeatRecipes([]);
        }}
        onCancel={() => {
          setRepeatOpen(false);
          setRepeatRecipes([]);
        }}
        repeatOpen={repeatOpen}
        values={repeatRecipes || {}}
      />

    </>
  )
}

export default CopyForm;