import React, { useState, useRef, useEffect } from 'react';
import { CloseOutlined } from '@ant-design/icons';
import { Modal, Form, Input, Button, InputNumber, TreeSelect, Card, Space, message } from 'antd';
import { ProCard } from '@ant-design/pro-Card';
import api from '../service';


const CreateAttrForm = (props) => {
  const [form] = Form.useForm();
  const [expandedCardKeys, setExpandedCardKeys] = useState([]);
  const [inputValues, setInputValues] = useState([]);

  useEffect(() => {
    if (props.values != undefined) {
      if (Object.keys(props.values).length > 0) {
        var inputs = props.values.map((item, index) => {
          return { index: index, value: item.name }
        })
        setInputValues(inputs)
      }
    }
    else {
      setInputValues({ index: 0, value: '' })
    }
    if (props.modalVisible) {
      form.resetFields();
      if (props.values) {
        form.setFieldsValue({ attrList: props.values });
      }
    }
  }, [props.values]);
  const toggleContent = (key) => {
    if (expandedCardKeys.includes(key)) {
      setExpandedCardKeys(expandedCardKeys.filter(k => k !== key));
    } else {
      setExpandedCardKeys([...expandedCardKeys, key]);
    }
  };
  const handleInputChange = (e, field) => {
    const updatedValues = [...inputValues];
    updatedValues[field.key] = { ...updatedValues[field.key], value: e.target.value };
    setInputValues(updatedValues);
  };

  return (
    <Modal
      key={Date.now}
      title='编辑属性'
      width={700}
      bodyStyle={{ padding: '32px 40px 1px 48px' }}
      visible={props.modalVisible}
      onCancel={props.onCancel}
      footer={null}
      maskClosable={false}
      destroyOnClose={true}
    >
      <Form
        labelCol={{
          span: 6,
        }}
        wrapperCol={{
          span: 18,
        }}
        form={form}
        name=""
        style={{
          maxWidth: 700,
        }}
        autoComplete="off"
        onFinish={props.onFinish}
      >
        <Form.List name="attrList">
          {(fields, { add, remove }) => (
            <div
              style={{
                display: 'flex',
                rowGap: 16,
                flexDirection: 'column',
              }}
            >
              {fields.map((field) => {
                const attrId = props.values[field.key]?.id;
                return (
                  <ProCard
                    size="small"
                    title={((inputValues[field?.key]?.value == undefined ? '' : inputValues[field?.key]?.value)) + (!expandedCardKeys.includes(field.key) ? '(点击收缩)' : '(点击展开)')}
                    key={field.key}
                    type='inner'
                    headerBordered
                    bordered
                    collapsible
                    onClick={() => toggleContent(field.key)}
                    extra={
                      <CloseOutlined
                        onClick={(e) => {
                          e.stopPropagation();
                          if (attrId == undefined) {
                            remove(field.name)
                            message.success("删除成功")
                          } else {
                            api.deleteRecipeAttribute(attrId, 1, props.autoKey).then((r) => {
                              if (r.data) {
                                message.success("删除成功")
                                remove(field.name)
                              } else {
                                message.error("删除失败：该属性已被使用！")
                              }
                            })
                          }
                        }}
                      />
                    }
                  >
                    {!expandedCardKeys.includes(field.key) && (
                      <div onClick={(e) => e.stopPropagation()}>
                        <Form.Item label="属性名称" name={[field.name, 'name']} rules={[{ required: true, max: 50 }]} style={{ display: 'inline-block', width: '50%' }}>
                          <Input placeholder="属性名称" onChange={(e) => handleInputChange(e, field)} />
                        </Form.Item>
                        <Form.Item label="序号" name={[field.name, 'sort']} rules={[{ required: true }]} style={{ display: 'inline-block', width: '50%' }}>
                          <InputNumber placeholder="序号" />
                        </Form.Item>
                        <Form.Item label="属性值" rules={[{ required: true, max: 50 }]} style={{ display: 'inline-block', width: '100%', marginLeft: '-12.5%' }}>
                          <Form.List name={[field.name, 'valueList']}>
                            {(subFields, subOpt) => (
                              <div
                                style={{
                                  display: 'flex',
                                  flexDirection: 'column',
                                  rowGap: 16,
                                }}
                              >
                                {subFields.map((subField) => {
                                  const valueId = props.values[field.key]?.valueList[subField.key]?.id;
                                  return (
                                    <Space key={subField.key}>
                                      <Form.Item noStyle name={[subField.name, 'name']}>
                                        <Input placeholder="属性值" />
                                      </Form.Item>
                                      <Form.Item noStyle name={[subField.name, 'sort']}>
                                        <Input placeholder="序号" />
                                      </Form.Item>
                                      <CloseOutlined
                                        onClick={() => {
                                          if (attrId == undefined) {
                                            message.success("删除成功")
                                            subOpt.remove(subField.name)
                                          } else {
                                            api.deleteRecipeAttribute(valueId, 2, props.autoKey).then((r) => {
                                              if (r.data) {
                                                message.success("删除成功")
                                                subOpt.remove(subField.name)
                                              } else {
                                                message.error("删除失败：该属性值已被使用！")
                                              }
                                            })
                                          }
                                        }}
                                      />
                                    </Space>
                                  )
                                })}
                                <Button type="dashed" block onClick={() => {
                                  var currentValueList = form.getFieldValue(['attrList', field.name, 'valueList']) || [];
                                  var maxSort = currentValueList.length > 0 ? Math.max(...currentValueList.map(item => item.sort || 0)) : 0;
                                  subOpt.add({ sort: maxSort + 1 });
                                }}>
                                  添加属性值
                                </Button>
                              </div>
                            )}
                          </Form.List>
                        </Form.Item>
                      </div>
                    )}
                  </ProCard>
                )
              })}
              <Button type="dashed" block onClick={() => {
                var maxSort = 0;
                if (fields.length != 0) {
                  maxSort = Math.max(...fields.map(field => form.getFieldValue(['attrList', field.name, 'sort']) || 0));
                }
                add({ sort: maxSort + 1 });
              }}>
                添加属性
              </Button>
            </div>
          )}
        </Form.List>
        <br />
        <Form.Item style={{ marginLeft: '72%', marginRight: '-7%' }}>
          <Button htmlType="button" style={{ float: 'right', left: 10 }} onClick={props.onCancel} >
            取消
          </Button>
          <Button type="primary" htmlType="submit" style={{ float: 'right' }} >
            保存
          </Button>
        </Form.Item>
      </Form>
    </Modal>
  )
}
export default CreateAttrForm;