
import { Button, Modal, Radio, Tag, message, Popconfirm, InputNumber } from 'antd';
import { ProCard } from '@ant-design/pro-Card';
import ProTable, { EditableProTable } from '@ant-design/pro-table';
import api from '../service';
import { useEffect, useRef, useState } from 'react';
import CreateAttrForm from './CreateAttrForm';

const RecipeDetailForm = (props) => {
  const actionRef = useRef()
  const [recipeAttrFormList, setRecipeAttrFormList] = useState([])
  const [recipeAttrList, setRecipeAttrList] = useState([])
  const [attrModalVisible, handleModalVisible] = useState(false)
  const [batchingList, setBatchingList] = useState([])
  const [editableKeys, setEditableRowKeys] = useState([])
  const [valueIds, setValueIds] = useState('')
  const [names, setNames] = useState('')

  useEffect(() => {
    getRecipeAttrList();
    getBaseBatchingList();
  }, []);
  const getRecipeAttrList = async () => {
    if (props.values?.id != undefined) {
      var data = await api.getRecipeAttributeList(props.values.id, props.autoKey);
      setRecipeAttrList(data.data);
    }
  }
  const getBaseBatchingList = async () => {
    if (props.values?.id != undefined) {
      var data = await api.getBaseBatchingList(props.values.id, props.autoKey);
      setEditableRowKeys(data.data.map((item) => item.id));
      setBatchingList(data.data);
    }
  }
  const getAttrBatchingList = async (valueIds) => {
    var data = await api.getAttrBatchingList(props.values.id, valueIds, props.autoKey);
    setEditableRowKeys(data.data.map((item) => item.id));
    setBatchingList(data.data);
  }
  const setRecipeBatching = async () => {
    var data = {};
    data.batchingList = batchingList;
    data.recipeVersionId = props.values.id;
    data.valueIds = valueIds == '' ? null : valueIds;
    data.autoKey = props.autoKey;
    await api.setRecipeBatching(data).then((r) => {
      if (r.data) {
        message.success("保存成功");
      } else {
        message.error(r.errors)
      }
      actionRef.current.reload()
    })
  }
  const onChangevalue = (e) => {
    const { value } = e.target;
    var valueIdList = [];
    var nameList = [];
    var newId = null;
    recipeAttrList.forEach(item => {
      item.valueList.forEach(x => {
        if (x.id == value) {
          newId = x.attributeId;
        }
      })
    })
    recipeAttrList.forEach(item => {
      if (item.id == newId) {
        item.valueList.forEach(x => {
          if (x.id == value) {
            item.defalutvalue = value;
          }
        }
        )
      }
    })
    recipeAttrList.forEach(x => {
      if (x.defalutvalue != undefined) {
        valueIdList.push(x.defalutvalue);
      }
      var name = x.valueList.find(t => t.id == x.defalutvalue)?.name;
      if (name != undefined) {
        nameList.push(name);
      }
    })
    var valueIds = valueIdList.join(',');
    setValueIds(valueIds);
    var names = nameList.join('-');
    setNames(names);
    setRecipeAttrList(recipeAttrList);
    setBatchingList([]);
    getAttrBatchingList(valueIds);
    actionRef.current.reload();
  }
  const cleanAttr = () => {
    setBatchingList([]);
    setValueIds('');
    recipeAttrList.forEach(item => {
      item.defalutvalue = null;
    })
    setRecipeAttrList(recipeAttrList);
    actionRef.current.reload();
  }
  const deleteRecipeAttr = (id) => {
    api.deleteRecipeAttr(id, props.autoKey).then((r) => {
      if (r.data) {
        message.success("删除成功")
      } else {
        message.error(r.errors)
      }
      if (valueIds != '') {
        setBatchingList([]);
      }
      actionRef.current.reload();
    })
  }
  const editAttrRecipe = (item) => {
    recipeAttrList.forEach(t => {
      t.valueList.forEach(x => {
        if (item.valueIds.includes(x.id)) {
          t.defalutvalue = x.id;
        }
      })
    })
    setValueIds(item.valueIds);
    setNames(item.name);
    setRecipeAttrList(recipeAttrList);
    setBatchingList(item.batchingList);
    setEditableRowKeys(item.batchingList.map((i) => i.id));
  }
  const setBaseBatchingList = async () => {
    var data = await api.getBaseBatchingList(props.values.id, props.autoKey);
    setEditableRowKeys(data.data.map((item) => item.id));
    setBatchingList(data.data);
  }
  const columns = [
    {
      title: '主键',
      dataIndex: 'id',
      key: 'id',
      hideInTable: true,
      hideInSearch: true,
      tip: '规则名称是唯一的 key',
    },
    {
      title: '物料Id',
      dataIndex: 'batchingId',
      hideInTable: true,
      hideInSearch: true
    },
    {
      title: '物料名称',
      dataIndex: 'name',
      hideInSearch: true,
      editable: false
    },
    {
      title: '用量(g)',
      dataIndex: 'weight',
      valueType: 'digit',
      hideInSearch: true,
      editable: true
    }
  ]
  const listColumns = [
    {
      title: '主键',
      dataIndex: 'id',
      key: 'id',
      hideInTable: true,
      hideInSearch: true,
      tip: '规则名称是唯一的 key',
    },
    {
      title: '多属性名称',
      dataIndex: 'name',
      hideInSearch: true
    },
    {
      title: '操作',
      dataIndex: 'option',
      valueType: 'option',
      fixed: 'right',
      render: (_, record) => [
        <a
          key="primary"
          type="primary"
          onClick={() => { editAttrRecipe(record) }}
        >
          查看
        </a>,
          <Popconfirm
            type="primary"
            key="primary"
            title="确认删除吗？"
            okText="是"
            cancelText="否"
            onConfirm={() => { deleteRecipeAttr(record.id) }}
            onCancel
          >
            <a href="#">删除</a>
          </Popconfirm>
      ]
    },
  ]
  return (
    <Modal
      title={ props.values?.version + '.0' + props.values?.name + (props.values?.isWeight ? '(计量模式)' : '(标准模式)')}
      width={1300}
      visible={props.detailModalOpen}
      onCancel={props.onCancel}
      footer={null}
      maskClosable={false}
      destroyOnClose
    >
      <ProCard split="vertical" style={{ height: '700px' }} >
        <div style={{ width: '50%', borderRight: '1px solid #f0f0f0' }}>
          <div style={{ height: '40%' }}>
            <ProCard
              title='属性'
              type='inner'
              colSpan="50%"
              height='50%'
            >
              {
                  <Button
                    type="primary"
                    key="primary"
                    onClick={() => {
                      setRecipeAttrFormList(recipeAttrList)
                      handleModalVisible(true)
                    }}
                  >
                    编辑属性
                  </Button>
              }
              <Button
                type="primary"
                key="primary"
                style={{ marginLeft: 10 }}
                onClick={() => {
                  getBaseBatchingList()
                  cleanAttr()
                }}
              >
                查看基础配方
              </Button>
              <Button
                type="dashed"
                style={{ float: 'right' }}
                onClick={() => { cleanAttr() }}
              >
                清空选择
              </Button>
              <div style={{ marginTop: 10, height: 150, overflowY: 'auto' }}>
                {
                  recipeAttrList == "" ? (<div>点击“编辑属性”添加属性和属性值!</div>) : (
                    recipeAttrList.map((item, index) => {
                      return (
                        <div style={{ marginTop: 10, width: 'max-content', overflowX: 'auto' }}>
                          <span><Tag color="blue">{item.name}</Tag>:</span>
                          <span>
                            <Radio.Group name={index} buttonStyle="solid" onChange={onChangevalue} value={item.defalutvalue}>
                              {
                                item.valueList.map((x, i) => {
                                  return (
                                    <Radio.Button key={i} name={i} value={x.id} style={{ marginLeft: 10 }}>{x.name}</Radio.Button>
                                  )
                                })
                              }
                            </Radio.Group>
                          </span>
                        </div>
                      )
                    })
                  )
                }
              </div>
            </ProCard>
          </div>
          <div style={{ height: '60%' }}>
            <ProTable
              headerTitle="列表"
              actionRef={actionRef}
              height='50%'
              search={false}
              pagination={{ defaultPageSize: 5 }}
              request={async () => {
                var data = [];
                await api.getAttrRecipeList(props.values.id, valueIds, props.autoKey).then((r) => {
                  data = r.data;
                });
                return {
                  data: data,
                  success: true
                };
              }}
              columns={listColumns}
            />
          </div>
        </div>
        <ProCard
          title={'配方' + (props.isWeight ? "(基准克数:" + (props.values?.referenceWeight == null ? '0' : props.values?.referenceWeight) + ")" : '')}
          type='inner'
          colSpan="50%"
        >
          <div style={{ position: 'relative', height: 600, overflow: 'hidden' }}>
            <div style={{ position: 'sticky', height: 50, top: 0, backgroundColor: '#fff', zIndex: 10 }}>
              <span style={{ color: '#FA541C', fontSize: 15, marginLeft: 25, height: 50, width: 280, display: 'inline-block', overflowY: 'auto' }}>
                {valueIds === '' ? '基础配方' : names}
              </span>
              <div style={{ float: 'right' }}>
                {
                    (valueIds === '' ? ("") : (
                      <Button
                        type="primary"
                        key="primary"
                        onClick={() => { setBaseBatchingList(); }}
                        style={{ marginRight: '8px' }}
                      >
                        填入基础配方数据
                      </Button>
                    ))
                }
                {
                    <Button
                      type="primary"
                      key="save"
                      onClick={() => { setRecipeBatching(); }}
                    >
                      保存数据
                    </Button>
                }
              </div>
            </div>
            <EditableProTable
              columns={columns}
              rowKey="id"
              height='530'
              value={batchingList}
              onChange={setBatchingList}
              recordCreatorProps={false}
              style={{ overflowY: 'auto', height: 'calc(100% - 30px)' }}
              editable={{
                type: 'multiple',
                editableKeys,
                onValuesChange: (record, recordList) => {
                  setBatchingList(recordList);
                },
              }}
            />
          </div>
        </ProCard>
      </ProCard>

      <CreateAttrForm
        key={Date.now()}
        onFinish={async (value) => {
          handleModalVisible(false);
          setRecipeAttrFormList([]);
          value.attrList.forEach((item) => {
            item.recipeVersionId = props.values.id
            item.autoKey = props.autoKey
          });
          await api.updateRecipeAttribute(value.attrList).then(r => {
            if (r.data) {
              if (value.attrList[0].id == undefined) {
                message.success("添加成功")
              }
              else {
                message.success("修改成功")
              }
              getRecipeAttrList()
            }
            else {
              message.error(r.errors)
            }
          })
        }}
        onCancel={() => {
          getRecipeAttrList();
          handleModalVisible(false);
          setRecipeAttrFormList([]);
        }}
        autoKey={props.autoKey}
        modalVisible={attrModalVisible}
        values={recipeAttrFormList || {}}
      />
    </Modal>
  )
}

export default RecipeDetailForm;