import { PlusOutlined } from '@ant-design/icons';
import ProTable from '@ant-design/pro-table';
import { Modal, Form, Select, Button, Input, InputNumber, Popconfirm, message } from 'antd';
import React, { useState, useRef, useEffect } from 'react';
import VersionCreateForm from './VersionCreateForm';
import RecipeDetailForm from './RecipeDetailForm';
import api from '../service';

const VersionForm = (props) => {
  const actionRef = useRef();
  const [createModalVisible, handleModalVisible] = useState(false);
  const [selectedRowsState, setSelectedRows] = useState();
  const [stepFormValues, setStepFormValues] = useState({});
  const [recipeVersion, setRecipeVersion] = useState();
  const [detailModalOpen, handleDetailModalOpen] = useState(false);

  const BatchDeletion = () => {
    return (
      selectedRowsState?.length > 0 &&
      (
        <Popconfirm
          title="确认删除吗?"
          onConfirm={onClickdele}
          okText="确定"
          cancelText="取消"
        >
          <Button type="primary">批量删除</Button>
        </Popconfirm>
      ))
  }
  const onClickdele = () => {
    handleRemove(selectedRowsState);
    setSelectedRows([]);
    actionRef.current?.reloadAndRest?.();
  }
  const handleRemove = async (selectedRows) => {
    if (!selectedRows) return true;
    await api.deleteRecipeVersion(selectedRows.map((row) => row.id), props.autoKey).then((r) => {
      if (r.data) {
        message.success('删除成功');
        actionRef.current.reload();
      } else {
        message.error(r.errors);
      }
    });
    return true;
  };

  const columns = [
    {
      title: '主键',
      dataIndex: 'id',
      tip: 'key',
      hideInSearch: true,
      hideInTable: true
    },
    {
      title: '版本',
      dataIndex: 'version',
      ellipsis: true,
      render: (text, record) => {
        return record.version ? `${record.version}.0` : '-';
      },
    },
    {
      title: '版本描述',
      dataIndex: 'describe',
      hideInSearch: true,
    },
    {
      title: '创建时间',
      dataIndex: 'createAt',
      valueType: 'date',
      hideInForm: true,
      hideInSearch: true,
    },
    {
      title: '操作',
      dataIndex: 'option',
      valueType: 'option',
      fixed: 'right',
      width: 200,
      render: (_, record) => [
        <a
          onClick={() => {
            handleModalVisible(true);
            setStepFormValues(record);
          }}
        >
          更新
        </a>,
        <a
          onClick={() => {
            var data = {};
            data.recipeId = props.values.id;
            data.name = props.values.name;
            data.isWeight = props.values.isWeight;
            data.referenceWeight = props.values.referenceWeight;
            data.id = record.id;
            data.version = record.version;
            setRecipeVersion(data)
            handleDetailModalOpen(true)
          }}
        >
          设置配方详情
        </a>
        ,
        <Popconfirm
          type="primary"
          key="primary"
          title="确认删除吗？"
          okText="是"
          cancelText="否"
          onConfirm={() => {
            api.deleteRecipeVersion([record.id], props.autoKey).then((r) => {
              if (r.succeeded) {
                message.success('删除成功');
                actionRef.current.reload();
              } else {
                message.error(r.errors);
              }
            });
          }}
        >
          <a href="#">删除</a>
        </Popconfirm>,
      ],
    }
  ]

  return (
    <>
      <Modal
        title='设置版本'
        width={1000}
        bodyStyle={{ padding: '32px 40px 1px 48px' }}
        visible={props.modalVisible}
        onCancel={props.onCancel}
        footer={null}
        maskClosable={false}
        destroyOnClose
      >
        <ProTable
          headerTitle="配方版本列表"
          actionRef={actionRef}
          rowKey="id"
          pagination={{ defaultPageSize: 10 }}
          search={false}
          toolBarRender={() => [
            <Button
              type="primary"
              key="primary"
              onClick={() => {
                api.getMaxVersion(props.values.id, props.autoKey).then((r)=>{
                  var maxSort = 0
                  if(r.data){
                    maxSort = r.data
                  }
                  var values = { version: maxSort + 1 }
                  setStepFormValues(values)
                  handleModalVisible(true)
                })
              }}
            >
              <PlusOutlined /> 新建
            </Button>,
            <BatchDeletion />
          ]}
          request={async () => {
            let recipeVeisionData = [];
            var total = 0;
            await api.getRecipeVersionList(props.values.id, props.autoKey).then((r) => {
              recipeVeisionData = r.data;
              total = r.data.length;
            });
            return {
              data: recipeVeisionData,
              total: total,
            };
          }}
          columns={columns}
          rowSelection={{
            onChange: (_, selectedRows) => {
              setSelectedRows(selectedRows);
            },
          }}
        />
      </Modal>

      <VersionCreateForm
        onFinish={async (value) => {
          setStepFormValues({});
          value.recipeId = props.values.id;
          value.autoKey = props.autoKey;
          await api.updateRecipeVersion(value).then((r) => {
            if (r.data) {
              if (value.id == undefined) {
                message.success("添加成功")
              }
              else {
                message.success("修改成功")
              }
            } else {
              message.error(r.errors)
            }
          })
          handleModalVisible(false);
          actionRef.current.reload();
        }}
        onCancel={() => {
          handleModalVisible(false);
          setStepFormValues({});
        }}
        modalVisible={createModalVisible}
        values={stepFormValues || {}}
      />

      <RecipeDetailForm
        key={Date.now()}
        onCancel={() => {
          handleDetailModalOpen(false)
          setRecipeVersion([])
        }}
        autoKey={props.autoKey}
        values={recipeVersion}
        detailModalOpen={detailModalOpen}
      />
    </>
  )
}

export default VersionForm;