import { PlusOutlined } from '@ant-design/icons';
import { Button, message, Popconfirm } from 'antd';
import React, { useState, useRef, useEffect } from 'react';
import { PageContainer } from '@ant-design/pro-layout';
import ProTable from '@ant-design/pro-table';
import CreateForm from './components/CreateForm';
import CopyForm from './components/CopyForm';
import api from './service';
import VersionForm from './components/VersionForm';

const recipeinfo = (props) => {
  const actionRef = useRef();
  const [autoKey, setAutokey] = useState();
  const [createModalVisible, handleModalVisible] = useState();
  const [versionVisible, handleVersionVisible] = useState();
  const [stepFormValues, setStepFormValues] = useState({});
  const [selectedRowsState, setSelectedRows] = useState();
  const [copyOpen, setCopyOpen] = useState(false);
  const [copyValues, setCopyValues] = useState(false);
  const typeList = [
    { value: false, label: '标准模式' },
    { value: true, label: '计量模式' },
  ];
  useEffect(() => {
    setAutokey(props.autoKey ? props.autoKey : 0);
  }, [])

  const BatchDeletion = () => {
    return (
      selectedRowsState?.length > 0 &&
      (
        <Popconfirm
          title="确认删除吗?"
          onConfirm={onClickdele}
          okText="确定"
          cancelText="取消"
        >
          <Button type="primary">批量删除</Button>
        </Popconfirm>
      ))
  }
  const onClickdele = () => {
    handleRemove(selectedRowsState);
    setSelectedRows([]);
    actionRef.current?.reloadAndRest?.();
  }
  const handleRemove = async (selectedRows) => {
    if (!selectedRows) return true;
    await api.deleteRecipeInfo(selectedRows.map((row) => row.id), autoKey).then((r) => {
      if (r.data) {
        message.success('删除成功');
        actionRef.current.reload();
      } else {
        message.error(r.errors);
      }
    });
    return true;
  };

  const columns = [
    {
      title: '主键',
      dataIndex: 'id',
      tip: 'key',
      hideInSearch: true,
      hideInTable: true
    },
    {
      title: '配方名称',
      dataIndex: 'name',
      ellipsis: true,
    },
    {
      title: '配方模式',
      dataIndex: 'isWeight',
      valueType: 'select',
      fieldProps: {
        options: typeList,
      },
    },
    {
      title: '基准克数',
      dataIndex: 'referenceWeight',
      hideInSearch: true,
      render: (text, record) => {
        return record.isWeight ? text : '-';
      },
    },
    {
      title: '创建时间',
      dataIndex: 'createAt',
      valueType: 'date',
      hideInForm: true,
      hideInSearch: true,
    },
    {
      title: '操作',
      dataIndex: 'option',
      valueType: 'option',
      fixed: 'right',
      width: 'auto',
      render: (_, record) => [
        <a
          onClick={() => {
            handleModalVisible(true);
            setStepFormValues(record);
          }}
        >
          更新
        </a>,
        <a
          onClick={() => {
            handleVersionVisible(true);
            setStepFormValues(record);
          }}
        >
          设置版本
        </a>
        ,
        <Popconfirm
          type="primary"
          key="primary"
          title="确认删除吗？"
          okText="是"
          cancelText="否"
          onConfirm={() => {
            api.deleteRecipeInfo([record.id], autoKey).then((r) => {
              if (r.succeeded) {
                message.success('删除成功');
                actionRef.current.reload();
              } else {
                message.error(r.errors);
              }
            });
          }}
        >
          <a href="#">删除</a>
        </Popconfirm>,
      ],
    }
  ]

  return (
    <PageContainer
      header={{
        title: '',
        breadcrumb: {},
      }}
    >
      <ProTable
        headerTitle="配方列表"
        actionRef={actionRef}
        rowKey="id"
        pagination={{ defaultPageSize: 10 }}
        search={{
          labelWidth: 120,
        }}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              api.getCopyList(autoKey).then((r)=>{
                if(r.data){
                  setCopyValues(r.data)
                }
              })
              setCopyOpen(true)
            }}
          >
            {
              props.autoKey ? "导入客户或设备数据" : "导入设备数据"
            }
          </Button>,
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              var values = { isWeight: false }
              setStepFormValues(values);
              handleModalVisible(true);
            }}
          >
            <PlusOutlined /> 新建
          </Button>,
          <BatchDeletion />
        ]}
        request={async (params) => {
          let recipeData = [];
          var total = 0;
          params.autoKey = autoKey;
          await api.getRecipeInfoPage(params).then((r) => {
            recipeData = r.data.data;
            total = r.data.total;
          });
          return {
            data: recipeData,
            total: total,
          };
        }}
        columns={columns}
        rowSelection={{
          onChange: (_, selectedRows) => {
            setSelectedRows(selectedRows);
          },
        }}
      />

      <CreateForm
        typeList={typeList}
        onFinish={async (value) => {
          setStepFormValues({});
          value.autoKey = autoKey;
          await api.updateRecipeInfo(value).then((r) => {
            if (r.data) {
              if (value.id == undefined) {
                message.success("添加成功")
              }
              else {
                message.success("修改成功")
              }
            } else {
              message.error(r.errors)
            }
          })
          handleModalVisible(false);
          actionRef.current.reload();
        }}
        onCancel={() => {
          handleModalVisible(false);
          setStepFormValues({});
        }}
        modalVisible={createModalVisible}
        values={stepFormValues || {}}
      />

      <CopyForm 
        onCancel={() => {
          setCopyOpen(false);
          actionRef.current.reload();
        }}
        copyOpen={copyOpen}
        autoKey={autoKey}
        values={copyValues}
      />

      <VersionForm
        onCancel={() => {
          handleVersionVisible(false);
          setStepFormValues({});
        }}
        autoKey={autoKey}
        modalVisible={versionVisible}
        values={stepFormValues || {}}
      />
    </PageContainer>
  )
}

export default recipeinfo;