import { Popconfirm, Modal, Select, message, Button } from 'antd';
import { useEffect, useState } from 'react';
import ProTable from '@ant-design/pro-table';
import api from '../service'

const CopyForm = (props) => {
  const [select, setSelect] = useState();
  const [tableValues, setTableValues] = useState();
  const [selcetValue, setSelectValue] = useState();
  const templateList = [
    { value: false, label: '基础模版' },
    { value: true, label: '设备模版' },
  ];
  useEffect(() => {
    setTableValues([])
  }, [props.copyOpen])
  const columns = [
    {
      title: '主键',
      dataIndex: 'id',
      tip: 'key',
      hideInSearch: true,
      hideInTable: true
    },
    {
      title: '模版/设备名称',
      dataIndex: 'name',
      ellipsis: true,
    },
  ]

  const changeSelect = (value) => {
    api.getTemplateList(value, props.autoKey, props.groupTempId).then((r) => {
      if (r.data) {
        setTableValues(r.data)
      }
    })
    setSelect(value)
  }

  return (
    <Modal
      title='导入数据'
      width={640}
      bodyStyle={{ padding: '10px' }}
      open={props.copyOpen}
      onCancel={props.onCancel}
      footer={null}
      maskClosable={false}
      destroyOnClose
    >
      <span style={{ marginLeft: 25, marginTop: 20 }}>数据来源:</span>
      <Select
        showSearch
        style={{ width: 300, marginLeft: 10 }}
        optionFilterProp="label"
        options={templateList}
        placeholder="请选择数据来源"
        allowClear
        onChange={(e) => { changeSelect(e) }}
      />

      <ProTable
        rowKey="id"
        columns={columns}
        dataSource={tableValues}
        options={false}
        search={false}
        style={{ marginTop: 10 }}
        pagination={{ defaultPageSize: 10 }}
        rowSelection={{
          type: 'radio',
          onChange: (selectedRowKeys, selectedRows) => {
            setSelectValue(selectedRowKeys)
          },
        }}
      />

      {
        selcetValue != undefined ? (
          <Popconfirm
            type="primary"
            key="primary"
            title="导入将覆盖自身模版"
            okText="是"
            cancelText="否"
            onConfirm={() => {
              const hide = message.loading('正在导入');
              setTimeout(() => {
                api.copyTemplateList(selcetValue, props.autoKey, props.groupTempId).then((r) => {
                  if (r.data) {
                    message.success("导入成功")
                  } else {
                    message.error(r.errors)
                  }
                })
                hide()
              }, 1000)
            }}
          >
            <Button
              type="primary"
              key="primary"
              style={{ float: 'right', marginTop: -25 }}
            >
              导入
            </Button>
          </Popconfirm>
        ) : ""
      }
    </Modal>
  )
}
export default CopyForm;