const buttonStyle = {
  width: '100%',
  height: '150px',
  textAlign: 'center',
  whiteSpace: 'normal'
}
const operateStyle = {
  position: 'absolute',
  top: '3%',
  right: '3%',
  border: 'none',
  background: 'transparent',
  cursor: 'pointer',
  color: '#FA541C',
}
const sortStyle = {
  position: 'absolute',
  top: '3%',
  right: '90%',
  border: 'none',
  background: 'transparent',
}
import api from '../service';
import React, { useState, useEffect } from 'react';
import { Button, message, Popconfirm } from 'antd';
import { CloseOutlined } from '@ant-design/icons';
import UpRecipeTemplateForm from './UpRecipeTemplateForm';

const RecipeTemplateForm = (props) => {
  const [modalVisible, handleModalVisible] = useState(false);
  const [recipeTemplate, setRecipeTemplate] = useState([]);
  const [filledValues, setFilledValues] = useState([]);

  useEffect(() => {
    fillValues(props.values)
  }, [props.values]);
  function fillValues(list) {
    var values = [];
    if (list.length == 0) {
      values = Array.from({ length: 20 }, (_, index) => {
        return {
          id: "",
          recipeGroupId: "",
          recipeId: "",
          recipeName: "",
          sort: index + 1,
          version: "",
          versionId: "",
          describe: ""
        }
      });
    }
    else {
      values = list
    }
    setFilledValues(values)
  }
  const getRecipeTemplateList = async (groupId, current) => {
    var data = await api.getRecipeTemplateList(groupId, current, props.autoKey);
    fillValues(data.data);
  }
  const deleteRecipeTemplate = async (id) => {
    await api.deleteRecipeTemplate(id, props.autoKey).then((r) => {
      if (r.data) {
        message.success('删除成功');
        getRecipeTemplateList(props.groupId, props.current);
      } else {
        message.error(r.errors);
      }
    });
  }
  return (
    <div style={{
      height: '90%',
      display: 'grid',
      gridTemplateColumns: 'repeat(5, 19%)',
      gridTemplateRows: 'repeat(4, 25%)',
      gap: '10px',
      justifyContent: 'center',
      alignItems: 'center'
    }}>
      {filledValues.map((item, index) => (
        <Button
          onClick={() => {
            if (props.groupId == undefined) {
              message.error("请先选择一个配方分组");
              return;
            }
            setRecipeTemplate(item)
            handleModalVisible(true)
          }}
          key={index}
          style={{
            ...buttonStyle,
            border: item.recipeName === "" ? '1px dashed #FA541C' : '1px solid #FA541C',
            backgroundColor: item.recipeName === "" ? '#ffffff' : '#fff2e8'
          }}
        >
          {
            item.recipeName != "" && (
              <span
                style={{...sortStyle}}
              >
                {item.sort}
              </span>
            )
          }
          {item.recipeName != "" && (
            <span
              style={{...operateStyle}}
            >
              {
                <a
                  onClick={(e) => {
                    e.stopPropagation()
                  }}
                  style={{ marginLeft: 5 }}
                >
                  <Popconfirm
                    title="确认删除吗?"
                    onConfirm={() => deleteRecipeTemplate(item.id)}
                    okText="确定"
                    cancelText="取消"
                  >
                    <CloseOutlined />
                  </Popconfirm>
                </a>
              }
            </span>
          )}
          {item.recipeName != "" ? item.recipeName : "+"}<br />
          {item.recipeName != "" ? item.version + ".0" : null}
        </Button>
      ))}

      <UpRecipeTemplateForm
        onFinish={async (value) => {
          setRecipeTemplate([]);
          handleModalVisible(false);
          value.recipeGroupId = props.groupId;
          value.autoKey = props.autoKey;
          await api.updateRecipeTemplate(value).then(r => {
            if (r.data) {
              if (value.id == undefined) {
                message.success("添加成功")
              }
              else {
                message.success("修改成功")
              }
              getRecipeTemplateList(props.groupId, props.current)
            }
            else {
              message.error(r.errors)
            }
          })
        }}
        onCancel={() => {
          handleModalVisible(false)
          setRecipeTemplate([])
        }}
        modalVisible={modalVisible}
        isWeight={props.isWeight}
        autoKey={props.autoKey}
        values={recipeTemplate || {}}
      />
    </div>
  );
};

export default RecipeTemplateForm;