import { Modal, Form, Button, Input, InputNumber, Select } from "antd";
import { useEffect, useState } from "react";
import api from '../service';

const UpdateRecipeInfoForm = (props) => {
  const [recipeList, setRecipeList] = useState([]);
  const [versionList, setVersionList] = useState([]);
  const [form] = Form.useForm();
  useEffect(() => {
    if (props.modalVisible) {
      form.setFieldsValue({ id: props.values.id, recipeId: props.values.recipeId, versionId: props.values.versionId, describe: props.values.describe, sort: props.values.sort })
      getRecipeVersionSelectList()
    }
  }, [props.values]);

  const getRecipeVersionSelectList = async () => {
    await api.getRecipeVersionSelectList(props.values.recipeId, props.isWeight, props.autoKey).then((r) => {
      if (r.data) {
        setRecipeList(r.data);
        var data = r.data.find(t => t.recipeId == props.values.recipeId);
        setVersionList(data?.versionList);
      }
    })
  }

  const handleRecipeChange = (value) => {
    form.setFieldsValue({ versionId: null, describe: null });
    var data = recipeList.find(t => t.recipeId == value);
    setVersionList(data.versionList);
  }

  return (
    <Modal
      title="绑定配方"
      width={640}
      bodyStyle={{ padding: '32px 40px 1px 48px' }}
      visible={props.modalVisible}
      onCancel={props.onCancel}
      footer={null}
      maskClosable={false}
      destroyOnClose
    >
      <Form
        layout="horizontal"
        preserve={false}
        labelCol={{
          span: 4,
        }}
        form={form}
        onFinish={props.onFinish}
      >
        <Form.Item name="id" hidden={true}>
          <Input />
        </Form.Item>
        <Form.Item name="recipeId" label="配方" rules={[{ required: true }]}>
          <Select
            showSearch
            optionFilterProp="label"
            onChange={handleRecipeChange}
            options={recipeList?.length > 0 ? recipeList.map((r) => ({ value: r.recipeId, label: r.name })) : ""}
            placeholder="请选择配方"
          />
        </Form.Item>
        <Form.Item name="versionId" label="版本" rules={[{ required: true }]}>
          <Select
            options={versionList?.length > 0 ? versionList.map((r) => ({ value: r.versionId, label: r.version })) : ""}
            placeholder="请选择版本"
            onChange={(e, index) => {
              var version = versionList.find(t => t.versionId == e);
              form.setFieldsValue({ describe: version.describe })
            }}
          />
        </Form.Item>
        <Form.Item name="describe" label="版本描述" >
          <Input disabled />
        </Form.Item>
        <Form.Item name="sort" label="序号" >
          <Input disabled />
        </Form.Item>
        <Form.Item>
          <Button htmlType="button" style={{ float: 'right', left: 10 }} onClick={props.onCancel}>
            取消
          </Button>
          <Button type="primary" htmlType="submit" style={{ float: 'right' }}>
            保存
          </Button>
        </Form.Item>
      </Form>
    </Modal>
  )
}

export default UpdateRecipeInfoForm;