import React, { useState, useEffect } from 'react';
import { PlusOutlined, FormOutlined, DeleteOutlined, CloseOutlined } from '@ant-design/icons';
import { PageContainer } from '@ant-design/pro-layout';
import { Button, message, Popconfirm, Pagination, Switch } from 'antd';
import { ProCard } from '@ant-design/pro-Card';
import api from './service';
import CreateForm from './components/CreateForm';
import CopyForm from './components/CopyForm';
import RecipeTemplateForm from './components/RecipeTemplateForm';

const recipetemplate = (props) => {
  const [autoKey, setAutokey] = useState();
  const [isWeight, setIsWeight] = useState(false);
  const [groupData, setGroupData] = useState([]);
  const [createModalVisible, handleModalVisible] = useState();
  const [recipeGroupValues, setRecipeGroupValues] = useState([]);
  const [recipeInfoValues, setRecipeInfoValues] = useState([]);
  const [groupId, setGroupId] = useState();
  const [current, setCurrent] = useState(1);
  const [defaultCurrent, setDefaultCurrent] = useState(1);
  const [total, setTotal] = useState(20);
  const [copyOpen, setCopyOpen] = useState(false);
  const isWeightList = [
    { value: false, label: '标准模式' },
    { value: true, label: '计量模式' },
  ];

  useEffect(() => {
    setAutokey(props.autoKey ? props.autoKey : 0);
    initGroupList(false);
  }, []);
  const initGroupList = async (isWeight) => {
    var data = await api.getRecipeGroupList(props.groupTempId ? props.groupTempId : "", isWeight, props.autoKey ? props.autoKey : 0);
    setGroupData(data.data);
  }
  const deleteGroup = async (id) => {
    await api.deleteRecipeGroup(id, autoKey).then((r) => {
      if (r.data) {
        message.success('删除成功');
        initGroupList(isWeight);
        setGroupId();
      } else {
        message.error(r.errors);
      }
    });
  }
  const getRecipeTemplateCount = async (id) => {
    var data = await api.getRecipeTemplateCount(id, autoKey);
    var total = data.data;
    if (total === 0) {
      total = 20
    }
    setTotal(total);
  }
  const getRecipeTemplateList = async (groupId, current) => {
    var data = await api.getRecipeTemplateList(groupId, current, autoKey);
    setRecipeInfoValues(data.data);
  }
  const addRecipeTemplatePage = async () => {
    if (groupId === undefined) {
      message.error("请先选择一个配方分组");
    } else {
      var data = {};
      data.recipeGroupId = groupId;
      await api.addRecipeTemplatePage(data, autoKey);
      var curr = total + 20;
      setTotal(curr)
      var current = Math.ceil(curr / 20);
      setCurrent(current)
      onChangepage(current)
    }
  }
  const deleteRecipeTemplatePage = async () => {
    if (groupId === undefined) {
      message.error("请先选择一个配方分组");
    } else {
      await api.deleteRecipeTemplatePage(groupId, current, autoKey).then((r) => {
        if (r.data) {
          message.success('删除成功')
          changeGroup(groupId)
        } else {
          message.error(r.errors);
        }
      })
    }
  }
  const onChangepage = (pageNumber) => {
    setCurrent(pageNumber)
    setDefaultCurrent(pageNumber)
    getRecipeTemplateList(groupId, pageNumber)
  };
  const changeGroup = async (id) => {
    setCurrent(1)
    setDefaultCurrent(1)
    setGroupId(id)
    getRecipeTemplateCount(id)
    getRecipeTemplateList(id, 1)
  }
  const switchOnChange = (checked) => {
    if (checked) {
      setIsWeight(true);
    } else {
      setIsWeight(false);
    }
    initGroupList(checked);
    setGroupId();
    setRecipeInfoValues([]);
  }
  return (
    <PageContainer
      header={{
        title: '',
        breadcrumb: {},
      }}
    >
      <div style={{ textAlign: 'left', marginBottom: 10 }}>
        <Button
          type="primary"
          key="primary"
          onClick={() => {
            setCopyOpen(true)
          }}
        >
          导入客户或设备数据
        </Button>
      </div>
      <ProCard style={{ height: '700px' }} split="vertical">
        <ProCard
          title='配方分组'
          type='inner'
          colSpan="25%"
          style={{ height: '800px', overflowY: 'auto' }}
          headStyle={{ position: 'sticky', top: 0, background: 'white', zIndex: 1 }}
          extra={
            <Button
              type="primary"
              key="primary"
              onClick={() => {
                api.getGroupMaxSort(isWeight, autoKey, props.groupTempId ? props.groupTempId : "").then((r) => {
                  var maxSort = 0
                  if (r.data) {
                    maxSort = r.data
                  }
                  var values = { sort: maxSort + 1 }
                  setRecipeGroupValues(values)
                  handleModalVisible(true)
                })
              }}
            >
              <PlusOutlined />添加分组
            </Button>
          }
        >
          <Switch
            checkedChildren="计量模式"
            unCheckedChildren="标准模式"
            defaultunChecked
            onChange={switchOnChange}
            style={{
              width: '100%',
              marginTop: -10,
              marginBottom: 10,
              backgroundColor: isWeight ? '#8F452B' : '#FA541C',
              borderColor: isWeight ? '#8F452B' : '#FA541C', 
            }}
          />
          <div>
            {
              groupData.length > 0 ? groupData.map(x => {
                const isSelected = x.id === groupId;
                return (
                  <ProCard
                    boxShadow
                    hoverable
                    bordered
                    key={x.id}
                    onClick={() => { changeGroup(x.id) }}
                    bodyStyle={{ padding: 15, display: 'flex', justifyContent: 'center' }}
                    headStyle={{ padding: '0px 24px' }}
                    style={{
                      marginBlockEnd: 8,
                      boxShadow: isSelected ? '-1px 5px 5px gray' : undefined,
                      borderColor: isSelected ? 'gray' : undefined,
                      borderWidth: '1px',
                      borderStyle: 'solid'
                    }}
                    extra={
                      <div style={{ height: 20 }}>
                        {
                          <FormOutlined
                            onClick={() => {
                              setRecipeGroupValues(x)
                              handleModalVisible(true)
                            }}
                          />
                        }
                        {
                          <Popconfirm
                            title="确认删除吗?"
                            onConfirm={() => deleteGroup(x.id)}
                            okText="确定"
                            cancelText="取消"
                          >
                            <DeleteOutlined style={{ marginLeft: 10 }} />
                          </Popconfirm>
                        }
                      </div>
                    }
                  >
                    <h1>{x.name}</h1>
                  </ProCard>
                )
              }) : <div>点击添加分组按钮添加配方分组!</div>
            }
          </div>
        </ProCard>
        <ProCard
          type='inner'
          title='配方'
          style={{ height: '800px' }}
        >
          <div style={{ height: '100%', overflow: 'hidden', clear: 'both' }}>
            <div style={{ textAlign: 'right', marginBottom: 10, marginRight: 10 }}>
              <Pagination
                style={{ display: 'inline-flex' }}
                current={current}
                defaultPageSize={20}
                defaultCurrent={defaultCurrent}
                total={total}
                onChange={onChangepage}
                showSizeChanger={false}
              />
              {
                <Button
                  type="primary"
                  style={{ marginLeft: 10 }}
                  onClick={() => addRecipeTemplatePage()}
                >
                  <PlusOutlined />新增页
                </Button>
              }
              {
                <Popconfirm
                  title="删除当前页和绑定配方?"
                  onConfirm={() => deleteRecipeTemplatePage()}
                  okText="确定"
                  cancelText="取消"
                >
                  <Button
                    type="primary"
                    style={{ marginLeft: 10 }}
                  >
                    <CloseOutlined />删除当前页
                  </Button>
                </Popconfirm>
              }
            </div>
            {
              <RecipeTemplateForm values={recipeInfoValues} current={current} groupId={groupId} isWeight={isWeight} autoKey={props.autoKey ? props.autoKey : 0} />
            }
          </div>
        </ProCard>
      </ProCard>

      <CopyForm
        onCancel={() => {
          setCopyOpen(false);
          initGroupList(false);
          changeGroup()
        }}
        copyOpen={copyOpen}
        autoKey={autoKey}
        groupTempId={props.groupTempId ? props.groupTempId : ""}
      />

      <CreateForm
        onFinish={async (value) => {
          setRecipeGroupValues([]);
          handleModalVisible(false);
          value.autoKey = autoKey;
          value.groupTempId = props.groupTempId ? props.groupTempId : "";
          await api.updataRecipeGroup(value).then(r => {
            if (r.data) {
              if (value.id == undefined) {
                message.success("添加成功")
              }
              else {
                message.success("修改成功")
              }
              initGroupList(isWeight);
            }
            else {
              message.error(r.errors)
            }
          })
          setGroupId();
        }}
        onCancel={() => {
          handleModalVisible(false);
          setRecipeGroupValues([]);
          setGroupId();
        }}
        modalVisible={createModalVisible}
        autoKey={autoKey}
        isWeight={isWeight}
        values={recipeGroupValues || {}}
        isWeightList={isWeightList}
      />
    </PageContainer>
  )
}

export default recipetemplate;