import { PageContainer } from "@ant-design/pro-layout";
import { DownloadOutlined } from '@ant-design/icons';
import { Tabs, Card, Input, DatePicker, Button, Select, message } from "antd"
import ProTable from '@ant-design/pro-table';
import React, { useState, useEffect } from 'react';
import moment from 'moment';
import api from "../service";
const { RangePicker } = DatePicker;

const batchingreport = () => {
  const [tabIndex, setTabIndex] = useState(1);
  const [batchingName, setBatchingName] = useState('');
  const [storeName, setStoreName] = useState('');
  const [deviceName, setDeviceName] = useState('');
  const [isWeight, setIsWeight] = useState();
  const [dataSource, setDataSource] = useState([]);
  const [loading, setLoading] = useState(false);
  const [timeRange, setTimeRange] = useState([
    moment().startOf('month'),
    moment().endOf('month'),
  ]);
  const isWeightList = [
    { value: false, label: '标准模式' },
    { value: true, label: '计量模式' },
  ];

  useEffect(() => {
    initData();
  }, [tabIndex]);

  const initData = async () => {
    setLoading(true)
    var data = [];
    if (tabIndex == 1) {
      data = await api.getBatchingUseSummary({ "batchingName": batchingName, "startTime": timeRange[0]._i, "endTime": timeRange[1]._i, "storeName": storeName, "deviceName": deviceName, "isWeight": isWeight });
    }
    setDataSource(data.data)
    setLoading(false)
  }

  const resetRequest = async () => {
    setLoading(true)
    setBatchingName('')
    setStoreName('')
    setDeviceName('')
    setIsWeight(null)
    var startDate = moment().startOf('month');
    var endDate = moment().endOf('month');
    setTimeRange([startDate, endDate])
    var data = []
    if (tabIndex == 1) {
      data = await api.getBatchingUseSummary({ "batchingName": "", "startTime": startDate, "endTime": endDate, "storeName": "", "deviceName": "", "isWeight": "" });
    }
    setDataSource(data.data)
    setLoading(false)
  }

  const handleDataDownload = async () => {
    const hide = message.loading('正在下载');
    var base64String = "";
    await api.downBatchingUseSummary({
      "batchingName": batchingName,
      "startTime": timeRange[0]._i,
      "endTime": timeRange[1]._i,
      "storeName": storeName,
      "deviceName": deviceName,
      "isWeight": isWeight
    }).then((r) => {
      if (r.data) {
        base64String = r.data
      }
    })
    const binaryString = atob(base64String);
    const bytes = new Uint8Array(binaryString.length);
    for (let i = 0; i < binaryString.length; i++) {
      bytes[i] = binaryString.charCodeAt(i);
    }
    const blob = new Blob([bytes], { type: 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet' });
    const url = window.URL.createObjectURL(blob);
    const link = document.createElement('a');
    const fileName = "物料使用汇总.xlsx";
    link.href = url;
    link.setAttribute('download', fileName);
    document.body.appendChild(link);
    link.click();
    document.body.removeChild(link);
    hide()
    message.success("导出成功")
  }

  const summaryColumns = [
    {
      title: '主键',
      dataIndex: 'id',
      tip: 'key',
      hideInSearch: true,
      hideInTable: true
    },
    {
      title: '物料名称',
      dataIndex: 'batchingName',
      hideInSearch: true,
      ellipsis: true,
    },
    {
      title: '门店名称',
      dataIndex: 'storeName',
      hideInSearch: true,
      ellipsis: true,
    },
    {
      title: '设备名称',
      dataIndex: 'deviceName',
      hideInSearch: true,
      ellipsis: true,
    },
    {
      title: '配方模式',
      dataIndex: 'isWeight',
      valueType: 'select',
      ellipsis: true,
      hideInSearch: true,
      fieldProps: {
        options: isWeightList,
      },
    },
    {
      title: '使用重量(g)',
      dataIndex: 'useWeight',
      hideInSearch: true,
      ellipsis: true,
    },
  ]
  return (
    <PageContainer
      header={{
        title: '',
        breadcrumb: {},
      }}
    >
      <Card style={{ marginBottom: 20 }}>
        <div style={{ display: 'flex', alignItems: 'center', width: '100%' }}>
          <span>物料名称:</span>
          <Input placeholder="请输入物料名称" style={{ width: '15%', margin: 10 }} value={batchingName} onChange={(a) => { setBatchingName(a.target.value) }} />
          <span>门店名称:</span>
          <Input placeholder="请输入门店名称" style={{ width: '15%', margin: 10 }} value={storeName} onChange={(a) => { setStoreName(a.target.value) }} />
          <span>设备名称:</span>
          <Input placeholder="请输入设备名称" style={{ width: '15%', margin: 10 }} value={deviceName} onChange={(a) => { setDeviceName(a.target.value) }} />
          <span>配方模式:</span>
          <Select
            value={isWeight}
            style={{ width: '15%', margin: 10 }}
            options={isWeightList}
            placeholder="请选择配方模式"
            allowClear
            onChange={(a) => { setIsWeight(a) }}
          />
        </div>
        <div style={{ display: 'flex', alignItems: 'center', width: '100%' }}>
          <span>使用时间:</span>
          <RangePicker showTime style={{ width: '25%', margin: 10 }} value={timeRange} onChange={(date, dateStrings) => {
            let tempDate = ['', '']
            if (date != null) {
              tempDate = [
                moment(moment(new Date(dateStrings[0])).format('YYYY-MM-DD HH:mm:ss')),
                moment(moment(new Date(dateStrings[1])).format('YYYY-MM-DD HH:mm:ss')),
              ]
            }
            setTimeRange(tempDate);
          }} />
          <Button onClick={() => { resetRequest() }}>
            重置
          </Button>
          <Button type="primary" style={{ marginLeft: 10 }} onClick={() => { initData() }}>
            查询
          </Button>
          <Button type="primary" style={{ marginLeft: 10 }} onClick={() => { handleDataDownload() }}>
            <DownloadOutlined />导出
          </Button>
        </div>
      </Card>
      <Card>
        <Tabs
          tabPosition={'left'}
          value={tabIndex}
          onChange={a => { setTabIndex(a) }}
          items={new Array(1).fill(null).map((_, i) => {
            const id = String(i + 1);
            return {
              label: '物料使用汇总',
              key: id,
              children:
                <ProTable
                  headerTitle="物料使用汇总"
                  rowKey="id"
                  pagination={{ defaultPageSize: 10 }}
                  search={false}
                  toolBarRender={false}
                  columns={summaryColumns}
                  dataSource={dataSource}
                  loading={loading}
                />
            }
          })}
        />
      </Card>
    </PageContainer>
  )
}

export default batchingreport;