import { PageContainer } from "@ant-design/pro-layout";
import { DownloadOutlined } from '@ant-design/icons';
import { Tabs, Card, Input, DatePicker, Button, Select, message } from "antd"
import ProTable from '@ant-design/pro-table';
import React, { useState, useEffect } from 'react';
import moment from 'moment';
import api from "../service";
const { RangePicker } = DatePicker;

const recipereport = () => {
  const [tabIndex, setTabIndex] = useState(1);
  const [recipeName, setRecipeName] = useState('');
  const [storeName, setStoreName] = useState('');
  const [deviceName, setDeviceName] = useState('');
  const [isWeight, setIsWeight] = useState();
  const [status, setStatus] = useState();
  const [dataSource, setDataSource] = useState([]);
  const [loading, setLoading] = useState(false);
  const [timeRange, setTimeRange] = useState([
    moment().startOf('month'),
    moment().endOf('month'),
  ]);
  const isWeightList = [
    { value: false, label: '标准模式' },
    { value: true, label: '计量模式' },
  ];
  const statusList = [
    { value: 1, label: '完成' },
    { value: 2, label: '强制终止' },
    { value: 3, label: '异常' },
  ]

  useEffect(() => {
    initData();
  }, [tabIndex]);

  const initData = async () => {
    setLoading(true)
    var data = [];
    if (tabIndex == 1) {
      data = await api.getRecipeUseDetail({ "recipeName": recipeName, "startTime": timeRange[0]._i, "endTime": timeRange[1]._i, "storeName": storeName, "deviceName": deviceName, "isWeight": isWeight, "status": status });
    } else {
      data = await api.getRecipeUseSummary({ "recipeName": recipeName, "startTime": timeRange[0]._i, "endTime": timeRange[1]._i, "storeName": storeName, "deviceName": deviceName, "isWeight": isWeight, "status": status });
    }
    setDataSource(data.data)
    setLoading(false)
  }

  const resetRequest = async () => {
    setLoading(true)
    setRecipeName('')
    setStoreName('')
    setDeviceName('')
    setIsWeight(null)
    setStatus(null)
    var startDate = moment().startOf('month');
    var endDate = moment().endOf('month');
    setTimeRange([startDate, endDate])
    var data = []
    if (tabIndex == 1) {
      data = await api.getRecipeUseDetail({ "recipeName": "", "startTime": startDate, "endTime": endDate, "storeName": "", "deviceName": "", "isWeight": "", "status": "" });
    } else {
      data = await api.getRecipeUseSummary({ "recipeName": "", "startTime": startDate, "endTime": endDate, "storeName": "", "deviceName": "", "isWeight": "", "status": "" });
    }
    setDataSource(data.data)
    setLoading(false)
  }

  const handleDataDownload = async () => {
    const hide = message.loading('正在下载');
    var base64String = "";
    if (tabIndex == 1) {
      await api.downRecipeUseDetail({
        "recipeName": recipeName,
        "startTime": timeRange[0]._i,
        "endTime": timeRange[1]._i,
        "storeName": storeName,
        "deviceName": deviceName,
        "isWeight": isWeight,
        "status": status
      }).then((r) => {
        if (r.data) {
          base64String = r.data
        }
      })
    }else{
      await api.downRecipeUseSummary({
        "recipeName": recipeName,
        "startTime": timeRange[0]._i,
        "endTime": timeRange[1]._i,
        "storeName": storeName,
        "deviceName": deviceName,
        "isWeight": isWeight,
        "status": status
      }).then((r) => {
        if (r.data) {
          base64String = r.data
        }
      })
    }
    const binaryString = atob(base64String);
    const bytes = new Uint8Array(binaryString.length);
    for (let i = 0; i < binaryString.length; i++) {
      bytes[i] = binaryString.charCodeAt(i);
    }
    const blob = new Blob([bytes], { type: 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet' });
    const url = window.URL.createObjectURL(blob);
    const link = document.createElement('a');
    const fileName = tabIndex == 1 ? "配方使用明细.xlsx" : "配方使用汇总.xlsx";
    link.href = url;
    link.setAttribute('download', fileName);
    document.body.appendChild(link);
    link.click();
    document.body.removeChild(link);
    hide()
    message.success("导出成功")
  }

  const detailColumns = [
    {
      title: '主键',
      dataIndex: 'id',
      tip: 'key',
      hideInSearch: true,
      hideInTable: true
    },
    {
      title: '配方名称',
      dataIndex: 'recipeName',
      ellipsis: true,
      hideInSearch: true,
    },
    {
      title: '门店名称',
      dataIndex: 'storeName',
      ellipsis: true,
      hideInSearch: true,
    },
    {
      title: '设备名称',
      dataIndex: 'deviceName',
      ellipsis: true,
      hideInSearch: true,
    },
    {
      title: '配方模式',
      dataIndex: 'isWeight',
      valueType: 'select',
      ellipsis: true,
      hideInSearch: true,
      fieldProps: {
        options: isWeightList,
      },
    },
    {
      title: '执行状态',
      dataIndex: 'status',
      valueType: 'select',
      ellipsis: true,
      hideInSearch: true,
      fieldProps: {
        options: statusList,
      },
    },
    {
      title: '使用时间',
      dataIndex: 'useDate',
      ellipsis: true,
      hideInSearch: true,
    },
  ]
  const summaryColumns = [
    {
      title: '主键',
      dataIndex: 'id',
      tip: 'key',
      hideInSearch: true,
      hideInTable: true
    },
    {
      title: '配方名称',
      dataIndex: 'recipeName',
      ellipsis: true,
      hideInSearch: true,
    },
    {
      title: '门店名称',
      dataIndex: 'storeName',
      ellipsis: true,
      hideInSearch: true,
    },
    {
      title: '设备名称',
      dataIndex: 'deviceName',
      ellipsis: true,
      hideInSearch: true,
    },
    {
      title: '配方模式',
      dataIndex: 'isWeight',
      valueType: 'select',
      ellipsis: true,
      hideInSearch: true,
      fieldProps: {
        options: isWeightList,
      },
    },
    {
      title: '执行状态',
      dataIndex: 'status',
      valueType: 'select',
      ellipsis: true,
      hideInSearch: true,
      fieldProps: {
        options: statusList,
      },
    },
    {
      title: '使用数量',
      dataIndex: 'useCount',
      ellipsis: true,
      hideInSearch: true,
    },
  ]
  return (
    <PageContainer
      header={{
        title: '',
        breadcrumb: {},
      }}
    >
      <Card style={{ marginBottom: 20 }}>
        <div style={{ display: 'flex', alignItems: 'center', width: '100%' }}>
          <span>配方名称:</span>
          <Input placeholder="请输入配方名称" style={{ width: '15%', margin: 10 }} value={recipeName} onChange={(a) => { setRecipeName(a.target.value) }} />
          <span>门店名称:</span>
          <Input placeholder="请输入门店名称" style={{ width: '15%', margin: 10 }} value={storeName} onChange={(a) => { setStoreName(a.target.value) }} />
          <span>设备名称:</span>
          <Input placeholder="请输入设备名称" style={{ width: '15%', margin: 10 }} value={deviceName} onChange={(a) => { setDeviceName(a.target.value) }} />
          <span>配方模式:</span>
          <Select
            value={isWeight}
            style={{ width: '15%', margin: 10 }}
            options={isWeightList}
            placeholder="请选择配方模式"
            allowClear
            onChange={(a) => { setIsWeight(a) }}
          />
        </div>
        <div style={{ display: 'flex', alignItems: 'center', width: '100%' }}>
          <span>执行状态:</span>
          <Select
            value={status}
            style={{ width: '15%', margin: 10 }}
            options={statusList}
            placeholder="请选择执行状态"
            allowClear
            onChange={(a) => { setStatus(a) }}
          />
          <span>使用时间:</span>
          <RangePicker showTime style={{ width: '25%', margin: 10 }} value={timeRange} onChange={(date, dateStrings) => {
            let tempDate = ['', '']
            if (date != null) {
              tempDate = [
                moment(moment(new Date(dateStrings[0])).format('YYYY-MM-DD HH:mm:ss')),
                moment(moment(new Date(dateStrings[1])).format('YYYY-MM-DD HH:mm:ss')),
              ]
            }
            setTimeRange(tempDate);
          }} />
          <Button onClick={() => { resetRequest() }}>
            重置
          </Button>
          <Button type="primary" style={{ marginLeft: 10 }} onClick={() => { initData() }}>
            查询
          </Button>
          <Button type="primary" style={{ marginLeft: 10 }} onClick={() => { handleDataDownload() }}>
            <DownloadOutlined />导出
          </Button>
        </div>
      </Card>
      <Card>
        <Tabs
          tabPosition={'left'}
          value={tabIndex}
          onChange={a => { setTabIndex(a) }}
          items={new Array(2).fill(null).map((_, i) => {
            const id = String(i + 1);
            return {
              label: id == 1 ? '配方使用明细' : '配方使用汇总',
              key: id,
              children: id == 1 ?
                <ProTable
                  headerTitle="配方使用明细"
                  rowKey="id"
                  pagination={{ defaultPageSize: 10 }}
                  search={false}
                  toolBarRender={false}
                  columns={detailColumns}
                  dataSource={dataSource}
                  loading={loading}
                />
                :
                <ProTable
                  headerTitle="配方使用汇总"
                  rowKey="id"
                  pagination={{ defaultPageSize: 10 }}
                  search={false}
                  toolBarRender={false}
                  columns={summaryColumns}
                  dataSource={dataSource}
                  loading={loading}
                />
            }
          })}
        />
      </Card>
    </PageContainer>
  )
}

export default recipereport;