import { PlusOutlined } from '@ant-design/icons';
import { Button, message, Popconfirm } from 'antd';
import React, { useState, useRef, useEffect } from 'react';
import { PageContainer } from '@ant-design/pro-layout';
import ProTable from '@ant-design/pro-table';
import CreateForm from './components/CreateForm';
import api from './service';

const storeinfo = () => {
  const actionRef = useRef();
  const [createModalOpen, handleModalOpen] = useState();
  const [stepFormValues, setStepFormValues] = useState({});
  const [selectedRowsState, setSelectedRows] = useState();
  const [treeData, setTreeData] = useState();
  useEffect(() => {
    initOrg()
  }, []);
  function initOrg() {
    api.gettree().then((r) => {
      setTreeData(r.data);
    });
  }
  const BatchDeletion = () => {
    return (
      selectedRowsState?.length > 0 &&
      (
        <Popconfirm
          title="确认删除吗?"
          onConfirm={onClickdele}
          okText="确定"
          cancelText="取消"
        >
          <Button type="primary">批量删除</Button>
        </Popconfirm>
      ))
  }
  const onClickdele = () => {
    handleRemove(selectedRowsState);
    setSelectedRows([]);
    actionRef.current?.reloadAndRest?.();
  }
  const handleRemove = async (selectedRows) => {
    if (!selectedRows) return true;
    await api.deleteStore(selectedRows.map((row) => row.id)).then((r) => {
      if (r.data) {
        message.success('删除成功');
        actionRef.current.reload();
      } else {
        message.error(r.errors);
      }
    });
    return true;
  };
  const columns = [
    {
      title: '主键',
      dataIndex: 'id',
      tip: 'key',
      hideInSearch: true,
      hideInTable: true
    },
    {
      title: '门店名称',
      dataIndex: 'name',
      ellipsis: true,
    },
    {
      title: '组织名称',
      dataIndex: 'orgName',
      ellipsis: true,
      hideInSearch: true,
    },
    {
      title: '负责人',
      dataIndex: 'header',
      ellipsis: true,
      hideInSearch: true,
    },
    {
      title: '手机号',
      dataIndex: 'phone',
      ellipsis: true,
      hideInSearch: true,
    },
    {
      title: '位置',
      dataIndex: 'position',
      ellipsis: true,
      hideInSearch: true,
    },
    {
      title: '描述',
      dataIndex: 'description',
      ellipsis: true,
      hideInSearch: true,
    },
    {
      title: '操作',
      dataIndex: 'option',
      valueType: 'option',
      fixed: 'right',
      width: 350,
      render: (_, record) => [
          <a
            onClick={() => {
              handleModalOpen(true);
              setStepFormValues(record);
            }}
          >
            更新
          </a>,
          <Popconfirm
            type="primary"
            key="primary"
            title="确认删除吗？"
            okText="是"
            cancelText="否"
            onConfirm={() => {
              api.deleteStore([record.id]).then((r) => {
                if (r.succeeded) {
                  message.success('删除成功');
                  actionRef.current.reload();
                } else {
                  message.error(r.errors);
                }
              });
            }}
          >
            <a href="#">删除</a>
          </Popconfirm>,
      ],
    }
  ]

  return (
    <PageContainer
      header={{
        title: '',
        breadcrumb: {},
      }}
    >
      <ProTable
        headerTitle="门店列表"
        actionRef={actionRef}
        rowKey="id"
        pagination={{ defaultPageSize: 10 }}
        search={{
          labelWidth: 120,
        }}
        toolBarRender={() => [
            <Button
              type="primary"
              key="primary"
              onClick={() => {
                handleModalOpen(true);
              }}
            >
              <PlusOutlined /> 新建
            </Button>,
            <BatchDeletion /> 
        ]}
        request={async (params) => {
          let storeData = [];
          var total = 0;
          await api.getStorePage(params).then((r) => {
            storeData = r.data.data;
            total = r.data.total;
          });
          return {
            data: storeData,
            total: total,
          };
        }}
        columns={columns}
        rowSelection={{
          onChange: (_, selectedRows) => {
            setSelectedRows(selectedRows);
          },
        }}
      />

      <CreateForm
        treeData={treeData}
        onFinish={async (value) => {
          await api.updateStore(value).then(r => {
            if (r.data) {
              if (value.id == undefined) {
                message.success("添加成功")
              }
              else {
                message.success("修改成功")
              }
            }
            else {
              message.error(r.errors)
            }
          })
          handleModalOpen(false);
          setStepFormValues({});
          actionRef.current.reload();
        }}
        onCancel={() => {
          handleModalOpen(false);
          setStepFormValues({});
        }}
        modalOpen={createModalOpen}
        values={stepFormValues || {}}
      />

    </PageContainer>
  )
}

export default storeinfo;