import React, { useState, useRef } from 'react';
import { Modal, Button, message, Popconfirm, Form, Input, DatePicker, Radio, Typography, InputNumber } from 'antd';
import { PageContainer } from '@ant-design/pro-layout';
import { PlusOutlined } from '@ant-design/icons';
import ProTable from '@ant-design/pro-table';
import dayjs from 'dayjs';
import weekday from "dayjs/plugin/weekday";
import localeData from "dayjs/plugin/localeData";
import api from './service';
const { Paragraph, Text } = Typography;
dayjs.extend(weekday);
dayjs.extend(localeData);
const dateFormat = 'YYYY/MM/DD';

const Activationinfo = () => {
  const actionRef = useRef();
  const [modalVisible, handleModalVisible] = useState(false);
  const [offlineVisible, handleOfflineVisible] = useState(false);
  const [logVisible, handleLogVisible] = useState(false);
  const [logValues, setLogValues] = useState();
  const [inputAutoKey, setInputAutoKey] = useState();
  const [offlineKey, setOfflineKey] = useState();
  const [disable, setDisable] = useState(false)
  const [form] = Form.useForm();
  const statusList = [
    { value: 1, label: '未激活' },
    { value: 2, label: '已激活' }
  ]

  const columns = [
    {
      title: '主键',
      dataIndex: 'id',
      hideInSearch: true,
      hideInTable: true,
      tip: '规则名称是唯一的 key'
    },
    {
      title: '激活码',
      dataIndex: 'onlineKey',
      hideInSearch: true,
      render: (text) => <Paragraph style={{ display: 'inline' }} copyable>{text}</Paragraph>,
    },
    {
      title: '有效日期',
      dataIndex: 'effectiveDate',
      hideInSearch: true,
      render: (_, record) => {
        var time = dayjs(record.effectiveDate, dateFormat).format('YYYY-MM-DD');
        return <span>{record.effectiveDate > '2050-01-01' ? "长期有效" : time}</span>
      }
    },
    {
      title: '状态',
      dataIndex: 'status',
      valueType: 'select',
      fieldProps: {
        options: statusList,
      },
    },
    {
      title: '设备',
      dataIndex: 'deviceName',
    },
    {
      title: '操作',
      dataIndex: 'option',
      valueType: 'option',
      fixed: 'right',
      width: 400,
      render: (_, record) => [
        <a
          disabled={record.status != 1 ? true : false}
          style={{ pointerEvents: record.status === 2 ? 'none' : 'auto' }}
          onClick={() => {
            var type = record.effectiveDate > '2050-01-01' ? "cqyx" : "gdsj";
            var time = record.effectiveDate > '2050-01-01' ? null : dayjs(record.effectiveDate, dateFormat);
            form.setFieldsValue({ id: record.id, autho: type, effectiveDate: time });
            handleModalVisible(true);
          }}
        >
          更新
        </a>,
        <a
          onClick={() => {
            if(record.status == 1){
              if(record.offlineKey)
                {
                  form.setFieldsValue({ id: record.id, autoKey: record.autoKey, offlineKey: record.offlineKey });
                  setDisable(true)
                  setInputAutoKey(null)
                  setOfflineKey(record.offlineKey)
                }
                else{
                  form.setFieldsValue({ id: record.id, autoKey: record.autoKey, offlineKey: record.offlineKey });
                  setDisable(false)
                  setInputAutoKey(record.autoKey)
                  setOfflineKey(record.offlineKey)
                }
            }else{
              form.setFieldsValue({ id: record.id, autoKey: record.autoKey, offlineKey: record.offlineKey });
              setDisable(true)
              setOfflineKey(record.offlineKey)
            }
            handleOfflineVisible(true)
          }}
        >
          离线激活码
        </a>,
        record.log != null ?
          <a
            onClick={() => {
              setLogValues(record.log)
              handleLogVisible(true)
            }}
          >
            激活记录
          </a> : "",
        <Popconfirm
          type="primary"
          key="primary"
          title="确认删除吗?"
          okText="是"
          cancelText="否"
          onConfirm={() => {
            api.deleteActivationInfo(record.id).then((r) => {
              if (r.data) {
                actionRef.current.reload();
                message.success("删除成功");
              } else {
                message.error(r.errors);
              }
            });
          }}
          onCancel={() => { }}
        >
          <a
            disabled={record.status != 1 ? true : false}
            style={{ pointerEvents: record.status != 1 ? 'none' : 'auto' }}
          >
            删除
          </a>
        </Popconfirm>
      ],
    },
  ];

  return (
    <PageContainer
      host
      header={{ title: '', breadcrumb: {}, }}
    >
      <ProTable
        actionRef={actionRef}
        rowKey="id"
        pagination={{ defaultPageSize: 10 }}
        search={{
          labelWidth: 120,
        }}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              handleModalVisible(true);
              form.setFieldsValue({ id: null, autho: "cqyx", effectiveDate: null });
            }} >
            <PlusOutlined /> 添加激活码
          </Button>,
        ]}
        request={async (params) => {
          var data = [];
          var total = 0;
          await api.getActivationInfoPage(params).then((r) => {
            data = r.data.data;
            total = r.data.total;
          });
          return {
            data: data,
            total: total,
          };
        }}
        columns={columns}
      />

      <Modal
        title="激活操作"
        width={640}
        open={modalVisible}
        onOk={() => {
          form.submit();
        }}
        onCancel={() => {
          handleModalVisible(false);
        }}
        maskClosable={false}
        destroyOnClose
      >
        <Form
          form={form}
          onFinish={async (value) => {
            await api.updateActivationInfo(value).then((r) => {
              if (r.data) {
                if (value.id == undefined) {
                  message.success("添加成功")
                }
                else {
                  message.success("修改成功")
                }
              } else {
                message.error(r.errors)
              }
            })
            handleModalVisible(false);
            actionRef.current.reload();
          }}
        >
          <Form.Item name="id" hidden={true}>
            <Input />
          </Form.Item>
          <Form.Item name="autho" label="激活时间" rules={[{ required: true }]} >
            <Radio.Group >
              <Radio value="cqyx"> 长期有效 </Radio>
              <Radio value="gdsj"> 固定时间 </Radio>
            </Radio.Group>
          </Form.Item>
          <Form.Item noStyle shouldUpdate={(prevValues, currentValues) => prevValues.autho !== currentValues.autho} >
            {({ getFieldValue }) =>
              getFieldValue('autho') == 'gdsj' ? (
                <Form.Item name="effectiveDate" label="固定时间" rules={[{ required: true, }]}>
                  <DatePicker style={{ width: "300px" }} />
                </Form.Item>
              ) : null
            }
          </Form.Item>
        </Form>
      </Modal>

      <Modal
        title="离线激活"
        width={400}
        open={offlineVisible}
        maskClosable={false}
        footer={false}
        onCancel={() => {
          handleOfflineVisible(false);
          form.resetFields();
          actionRef.current.reload();
        }}
        destroyOnClose
      >
        <Form
          form={form}
        >
          <Form.Item name="id" hidden={true}>
            <Input />
          </Form.Item>
          <Form.Item name="autoKey" label="设备唯一key" rules={[{ required: true }]} >
            <InputNumber
              disabled={disable}
              style={{ width: '40%' }}
              parser={value => {
                const integerPart = value.split('.')[0];
                return integerPart.replace(/[^\d]/g, '');
              }} 
              step={1}
              onChange={(e) => {
                setInputAutoKey(e)
              }}
            />
          </Form.Item>
          {
            inputAutoKey && (
              <Button
                type="primary"
                key="primary"
                style={{ marginLeft: 10, marginTop: -56, float: 'right' }}
                onClick={() => {
                  var requestData = {
                    id: form.getFieldValue('id'),
                    autoKey: inputAutoKey,
                  };
                  api.updateOfflineKey(requestData).then((r) => {
                    if (r.data) {
                      setOfflineKey(r.data)
                      setInputAutoKey()
                      setDisable(true)
                      form.setFieldsValue({ offlineKey: r.data });
                      message.success("生成成功")
                    }
                    else {
                      message.error(r.errors)
                    }
                  })
                }}
              >
                生成离线激活码
              </Button>
            )
          }
          {
            offlineKey && (
              <Form.Item name="offlineKey" label="离线激活码">
                <Paragraph style={{ display: 'inline' }} copyable>{offlineKey}</Paragraph>
              </Form.Item>
            )
          }
        </Form>
      </Modal>

      <Modal
        title="激活记录"
        width={640}
        open={logVisible}
        onCancel={() => {
          handleLogVisible(false);
        }}
        maskClosable={false}
        destroyOnClose
      >
        <div style={{ padding: 15 }}>
          <h3>激活方式：<span style={{ color: "#FA541C" }}>{logValues?.onlineKey === null ? "离线激活" : "在线激活"}</span></h3>
          <h3>激活码：<span style={{ color: "#FA541C" }}>{logValues?.onlineKey === null ? logValues?.offlineKey : logValues?.onlineKey}</span></h3>
          <h3>激活时间：<span style={{ color: "#FA541C" }}>{logValues?.activationDate}</span></h3>
          <h3>激活设备Key：<span style={{ color: "#FA541C" }}>{logValues?.autoKey}</span></h3>
          <h3>激活设备：<span style={{ color: "#FA541C" }}>{logValues?.deviceName}</span></h3>
          <h3>激活加盟商：<span style={{ color: "#FA541C" }}>{logValues?.company}</span></h3>
        </div>
      </Modal>
    </PageContainer>
  );
};

export default Activationinfo;
